! This file has been generated automatically
! sqrt(3) has been replaced manually by a parameter called sqrt3

! transformation rules for matrix elements of dipole operator
DOUBLE PRECISION FUNCTION slako_transformation_dipole(r,x,y,z, Dip, N, l1,m1, mr, l2,m2)
   IMPLICIT NONE
   ! x,y,z are directional cosines, r is the distance between the two centers
   DOUBLE PRECISION, INTENT(IN) :: r,x,y,z
   INTEGER, INTENT(IN) :: N  ! length of array Dip
   ! values of the N Slater-Koster tables for the dipole evaluated at distance r
   DOUBLE PRECISION, INTENT(IN) :: Dip(N)
   ! orbital qm numbers for center 1 and center 2
   INTEGER, INTENT(IN) :: l1,m1,l2,m2
   ! qm number for orientation of r-vector, -1: y, 0: z, 1: x
   INTEGER, INTENT(IN) :: mr
   ! Local Variables
   INTEGER, PARAMETER :: lmax=2
   ! Result D(x,y,z)=<l1,m1|r_(lr,mr)|l2,m2> after applying SK rules
   DOUBLE PRECISION :: res
   INTEGER :: i  ! index that encodes the tuple (l1,m1,mr,l2,m2)

   DOUBLE PRECISION, PARAMETER :: sqrt3 = sqrt(3.0)
   
   ! First we need to transform the tuple (l1,m1,mr,l2,m2) into a unique integer
   ! so that the compiler can build a branching table for each case.
   ! Valid ranges for qm numbers: 0 <= l1,l2 <= lmax, -lmax <= m1,m2 <= lmax and -1 <= mr <= 1
   i = (mr+1)*10000+l1*1000+(lmax+m1)*100+l2*10+(lmax+m2)
   SELECT CASE(i)
	CASE (202)
	! (0,0,-1,0,0)
	 res = y*Dip(4)
	CASE (211)
	! (0,0,-1,1,-1)
	 res = (x**2 + z**2)*Dip(2) + y**2*Dip(5)
	CASE (212)
	! (0,0,-1,1,0)
	 res = y*z*(-Dip(2) + Dip(5))
	CASE (213)
	! (0,0,-1,1,1)
	 res = x*y*(-Dip(2) + Dip(5))
	CASE (220)
	! (0,0,-1,2,-2)
	 res = x*((x**2 - y**2 + z**2)*Dip(3) + y**2*Dip(6)*sqrt3)
	CASE (221)
	! (0,0,-1,2,-1)
	 res = z*((x**2 - y**2 + z**2)*Dip(3) + y**2*Dip(6)*sqrt3)
	CASE (222)
	! (0,0,-1,2,0)
	 res = -(y*((x**2 + y**2 - 2*z**2)*Dip(6) + 2*z**2*Dip(3)*sqrt3))/2.
	CASE (223)
	! (0,0,-1,2,1)
	 res = x*y*z*(-2*Dip(3) + Dip(6)*sqrt3)
	CASE (224)
	! (0,0,-1,2,2)
	 res = -(y*(2*(2*x**2 + z**2)*Dip(3) + (-x**2 + y**2)*Dip(6)*sqrt3))/2.
	CASE (10202)
	! (0,0,0,0,0)
	 res = z*Dip(4)
	CASE (10211)
	! (0,0,0,1,-1)
	 res = y*z*(-Dip(2) + Dip(5))
	CASE (10212)
	! (0,0,0,1,0)
	 res = (x**2 + y**2)*Dip(2) + z**2*Dip(5)
	CASE (10213)
	! (0,0,0,1,1)
	 res = x*z*(-Dip(2) + Dip(5))
	CASE (10220)
	! (0,0,0,2,-2)
	 res = x*y*z*(-2*Dip(3) + Dip(6)*sqrt3)
	CASE (10221)
	! (0,0,0,2,-1)
	 res = y*((x**2 + y**2 - z**2)*Dip(3) + z**2*Dip(6)*sqrt3)
	CASE (10222)
	! (0,0,0,2,0)
	 res = z**3*Dip(6) - ((x**2 + y**2)*z*(Dip(6) - 2*Dip(3)*sqrt3))/2.
	CASE (10223)
	! (0,0,0,2,1)
	 res = x*((x**2 + y**2 - z**2)*Dip(3) + z**2*Dip(6)*sqrt3)
	CASE (10224)
	! (0,0,0,2,2)
	 res = -((x - y)*(x + y)*z*(2*Dip(3) - Dip(6)*sqrt3))/2.
	CASE (20202)
	! (0,0,1,0,0)
	 res = x*Dip(4)
	CASE (20211)
	! (0,0,1,1,-1)
	 res = x*y*(-Dip(2) + Dip(5))
	CASE (20212)
	! (0,0,1,1,0)
	 res = x*z*(-Dip(2) + Dip(5))
	CASE (20213)
	! (0,0,1,1,1)
	 res = (y**2 + z**2)*Dip(2) + x**2*Dip(5)
	CASE (20220)
	! (0,0,1,2,-2)
	 res = y*((-x**2 + y**2 + z**2)*Dip(3) + x**2*Dip(6)*sqrt3)
	CASE (20221)
	! (0,0,1,2,-1)
	 res = x*y*z*(-2*Dip(3) + Dip(6)*sqrt3)
	CASE (20222)
	! (0,0,1,2,0)
	 res = -(x*((x**2 + y**2 - 2*z**2)*Dip(6) + 2*z**2*Dip(3)*sqrt3))/2.
	CASE (20223)
	! (0,0,1,2,1)
	 res = z*((-x**2 + y**2 + z**2)*Dip(3) + x**2*Dip(6)*sqrt3)
	CASE (20224)
	! (0,0,1,2,2)
	 res = x*(2*y**2 + z**2)*Dip(3) + (x*(x - y)*(x + y)*Dip(6)*sqrt3)/2.
	CASE (1102)
	! (1,-1,-1,0,0)
	 res = (x**2 + z**2)*Dip(7) + y**2*Dip(14)
	CASE (1111)
	! (1,-1,-1,1,-1)
	 res = y*(x**2 + z**2)*(Dip(8) + 2*Dip(9)) + y**3*Dip(15)
	CASE (1112)
	! (1,-1,-1,1,0)
	 res = z*((x**2 + z**2)*Dip(8) + y**2*(-2*Dip(9) + Dip(15)))
	CASE (1113)
	! (1,-1,-1,1,1)
	 res = x*((x**2 + z**2)*Dip(8) + y**2*(-2*Dip(9) + Dip(15)))
	CASE (1120)
	! (1,-1,-1,2,-2)
	 res = (x*y*(-(y**2*z**2*(x**2 + y**2 + 2*z**2)*Dip(11)) + 2*(x**2 + y**2)**2*(x**2 - &
y**2 + z**2)*Dip(12) - (x**4 + x**2*y**2 + 2*y**2*z**2)*Dip(13) + (x**2 + &
y**2)**2*((x**2 + z**2)*Dip(10) + y**2*Dip(16))*sqrt3))/(x**2 + y**2)**2
	CASE (1121)
	! (1,-1,-1,2,-1)
	 res = (y*z*(y**2*z**2*Dip(11) + 2*(x**2 + y**2)*(x**2 - y**2 + z**2)*Dip(12) - &
x**2*Dip(13) + (x**2 + y**2)*((x**2 + z**2)*Dip(10) + &
y**2*Dip(16))*sqrt3))/(x**2 + y**2)
	CASE (1122)
	! (1,-1,-1,2,0)
	 res = (-((x**2 + y**2 - 2*z**2)*((x**2 + z**2)*Dip(10) + y**2*Dip(16))) - &
(y**2*z**2*(Dip(11) + 4*Dip(12)) + x**2*(x**2 + y**2 + &
z**2)*Dip(13))*sqrt3)/2.
	CASE (1123)
	! (1,-1,-1,2,1)
	 res = (x*z*(y**2*z**2*Dip(11) - 4*y**2*(x**2 + y**2)*Dip(12) + (x**2 + &
2*y**2)*Dip(13) + (x**2 + y**2)*((x**2 + z**2)*Dip(10) + &
y**2*Dip(16))*sqrt3))/(x**2 + y**2)
	CASE (1124)
	! (1,-1,-1,2,2)
	 res = (y**2*(-x + y)*(x + y)*z**2*(x**2 + y**2 + 2*z**2)*Dip(11) - 4*y**2*(x**2 + &
y**2)**2*(2*x**2 + z**2)*Dip(12) - x**2*(x**4 - y**4 + 2*(x**2 + &
3*y**2)*z**2)*Dip(13) + (x - y)*(x + y)*(x**2 + y**2)**2*((x**2 + &
z**2)*Dip(10) + y**2*Dip(16))*sqrt3)/(2.*(x**2 + y**2)**2)
	CASE (11102)
	! (1,-1,0,0,0)
	 res = y*z*(-Dip(7) + Dip(14))
	CASE (11111)
	! (1,-1,0,1,-1)
	 res = z*(-(y**2*Dip(8)) + (x**2 - y**2 + z**2)*Dip(9) + y**2*Dip(15))
	CASE (11112)
	! (1,-1,0,1,0)
	 res = y*((x**2 + y**2)*Dip(9) - z**2*(Dip(8) + Dip(9) - Dip(15)))
	CASE (11113)
	! (1,-1,0,1,1)
	 res = x*y*z*(-Dip(8) - 2*Dip(9) + Dip(15))
	CASE (11120)
	! (1,-1,0,2,-2)
	 res = (x*z*(y**2*(x**2 + y**2 + 2*z**2)*Dip(11) + (x**2 + y**2)*(x**2 - 3*y**2 + &
z**2)*Dip(12) + (-x**2 + y**2)*Dip(13) - y**2*(x**2 + y**2)*(Dip(10) - &
Dip(16))*sqrt3))/(x**2 + y**2)
	CASE (11121)
	! (1,-1,0,2,-1)
	 res = -(y**2*z**2*Dip(11)) + ((y**2 - z**2)**2 + x**2*(y**2 + z**2))*Dip(12) + &
x**2*(x**2 + y**2 + z**2)*Dip(13) + y**2*z**2*(-Dip(10) + Dip(16))*sqrt3
	CASE (11122)
	! (1,-1,0,2,0)
	 res = (y*z*((x**2 + y**2 - 2*z**2)*(Dip(10) - Dip(16)) + ((x**2 + y**2)*Dip(11) + &
2*(x**2 + y**2 - z**2)*Dip(12))*sqrt3))/2.
	CASE (11123)
	! (1,-1,0,2,1)
	 res = x*y*((x**2 + y**2)*(Dip(12) - Dip(13)) - z**2*(Dip(11) + 3*Dip(12) + Dip(13) + &
(Dip(10) - Dip(16))*sqrt3))
	CASE (11124)
	! (1,-1,0,2,2)
	 res = (y*z*((x - y)*(x + y)*(x**2 + y**2 + 2*z**2)*Dip(11) - 2*(x**2 + y**2)*(3*x**2 &
- y**2 + z**2)*Dip(12) + 4*x**2*Dip(13) - (x**4 - y**4)*(Dip(10) - &
Dip(16))*sqrt3))/(2.*(x**2 + y**2))
	CASE (21102)
	! (1,-1,1,0,0)
	 res = x*y*(-Dip(7) + Dip(14))
	CASE (21111)
	! (1,-1,1,1,-1)
	 res = x*(-(y**2*Dip(8)) + (x**2 - y**2 + z**2)*Dip(9) + y**2*Dip(15))
	CASE (21112)
	! (1,-1,1,1,0)
	 res = x*y*z*(-Dip(8) - 2*Dip(9) + Dip(15))
	CASE (21113)
	! (1,-1,1,1,1)
	 res = y*(-(x**2*Dip(8)) + (-x**2 + y**2 + z**2)*Dip(9) + x**2*Dip(15))
	CASE (21120)
	! (1,-1,1,2,-2)
	 res = (-(x**2*y**2*z**2*(x**2 + y**2 + 2*z**2)*Dip(11)) + (x**2 + y**2)**2*((x**2 - &
y**2)**2 + (x**2 + y**2)*z**2)*Dip(12) + (x**2*y**2*(x**2 + y**2) + (x**4 + &
y**4)*z**2)*Dip(13) - y**2*(x**3 + x*y**2)**2*(Dip(10) - &
Dip(16))*sqrt3)/(x**2 + y**2)**2
	CASE (21121)
	! (1,-1,1,2,-1)
	 res = (x*z*(y**2*z**2*Dip(11) + (x**2 + y**2)*(x**2 - 3*y**2 + z**2)*Dip(12) - &
x**2*Dip(13) - y**2*(x**2 + y**2)*(Dip(10) - Dip(16))*sqrt3))/(x**2 + y**2)
	CASE (21122)
	! (1,-1,1,2,0)
	 res = (x*y*((x**2 + y**2 - 2*z**2)*(Dip(10) - Dip(16)) + (-(z**2*(Dip(11) + &
4*Dip(12))) + (x**2 + y**2 + z**2)*Dip(13))*sqrt3))/2.
	CASE (21123)
	! (1,-1,1,2,1)
	 res = (y*z*(x**2*z**2*Dip(11) - y**2*Dip(13) - x**2*(x**2 + y**2)*Dip(10)*sqrt3 + &
(x**2 + y**2)*((-3*x**2 + y**2 + z**2)*Dip(12) + x**2*Dip(16)*sqrt3)))/(x**2 &
+ y**2)
	CASE (21124)
	! (1,-1,1,2,2)
	 res = (x*(x - y)*y*(x + y)*(-(z**2*(x**2 + y**2 + 2*z**2)*Dip(11)) - 4*(x**2 + &
y**2)**2*Dip(12) + (x**2 + y**2 - 2*z**2)*Dip(13) - (x**2 + y**2)**2*(Dip(10) &
- Dip(16))*sqrt3))/(2.*(x**2 + y**2)**2)
	CASE (1202)
	! (1,0,-1,0,0)
	 res = y*z*(-Dip(7) + Dip(14))
	CASE (1211)
	! (1,0,-1,1,-1)
	 res = z*(-(y**2*Dip(8)) + (x**2 - y**2 + z**2)*Dip(9) + y**2*Dip(15))
	CASE (1212)
	! (1,0,-1,1,0)
	 res = y*((x**2 + y**2)*Dip(9) - z**2*(Dip(8) + Dip(9) - Dip(15)))
	CASE (1213)
	! (1,0,-1,1,1)
	 res = x*y*z*(-Dip(8) - 2*Dip(9) + Dip(15))
	CASE (1220)
	! (1,0,-1,2,-2)
	 res = (x*z*(y**2*(x**2 + y**2 + 2*z**2)*Dip(11) + (x**2 + y**2)*(x**2 - 3*y**2 + &
z**2)*Dip(12) + (-x**2 + y**2)*Dip(13) - y**2*(x**2 + y**2)*(Dip(10) - &
Dip(16))*sqrt3))/(x**2 + y**2)
	CASE (1221)
	! (1,0,-1,2,-1)
	 res = -(y**2*z**2*Dip(11)) + ((y**2 - z**2)**2 + x**2*(y**2 + z**2))*Dip(12) + &
x**2*(x**2 + y**2 + z**2)*Dip(13) + y**2*z**2*(-Dip(10) + Dip(16))*sqrt3
	CASE (1222)
	! (1,0,-1,2,0)
	 res = (y*z*((x**2 + y**2 - 2*z**2)*(Dip(10) - Dip(16)) + ((x**2 + y**2)*Dip(11) + &
2*(x**2 + y**2 - z**2)*Dip(12))*sqrt3))/2.
	CASE (1223)
	! (1,0,-1,2,1)
	 res = x*y*((x**2 + y**2)*(Dip(12) - Dip(13)) - z**2*(Dip(11) + 3*Dip(12) + Dip(13) + &
(Dip(10) - Dip(16))*sqrt3))
	CASE (1224)
	! (1,0,-1,2,2)
	 res = (y*z*((x - y)*(x + y)*(x**2 + y**2 + 2*z**2)*Dip(11) - 2*(x**2 + y**2)*(3*x**2 &
- y**2 + z**2)*Dip(12) + 4*x**2*Dip(13) - (x**4 - y**4)*(Dip(10) - &
Dip(16))*sqrt3))/(2.*(x**2 + y**2))
	CASE (11202)
	! (1,0,0,0,0)
	 res = (x**2 + y**2)*Dip(7) + z**2*Dip(14)
	CASE (11211)
	! (1,0,0,1,-1)
	 res = y*((x**2 + y**2)*Dip(8) + z**2*(-2*Dip(9) + Dip(15)))
	CASE (11212)
	! (1,0,0,1,0)
	 res = (x**2 + y**2)*z*(Dip(8) + 2*Dip(9)) + z**3*Dip(15)
	CASE (11213)
	! (1,0,0,1,1)
	 res = x*((x**2 + y**2)*Dip(8) + z**2*(-2*Dip(9) + Dip(15)))
	CASE (11220)
	! (1,0,0,2,-2)
	 res = x*y*(-((x**2 + y**2 + 2*z**2)*Dip(11)) + (x**2 + y**2)*Dip(10)*sqrt3 + &
z**2*(-4*Dip(12) + Dip(16)*sqrt3))
	CASE (11221)
	! (1,0,0,2,-1)
	 res = y*(x**2 + y**2)*z*(Dip(11) + 2*Dip(12) + Dip(10)*sqrt3) + y*z**3*(-2*Dip(12) &
+ Dip(16)*sqrt3)
	CASE (11222)
	! (1,0,0,2,0)
	 res = (-((x**2 + y**2 - 2*z**2)*((x**2 + y**2)*Dip(10) + z**2*Dip(16))) - (x**2 + &
y**2)*((x**2 + y**2)*Dip(11) - 4*z**2*Dip(12))*sqrt3)/2.
	CASE (11223)
	! (1,0,0,2,1)
	 res = x*(x**2 + y**2)*z*(Dip(11) + 2*Dip(12) + Dip(10)*sqrt3) + x*z**3*(-2*Dip(12) &
+ Dip(16)*sqrt3)
	CASE (11224)
	! (1,0,0,2,2)
	 res = ((x - y)*(x + y)*(-((x**2 + y**2 + 2*z**2)*Dip(11)) + (x**2 + &
y**2)*Dip(10)*sqrt3 + z**2*(-4*Dip(12) + Dip(16)*sqrt3)))/2.
	CASE (21202)
	! (1,0,1,0,0)
	 res = x*z*(-Dip(7) + Dip(14))
	CASE (21211)
	! (1,0,1,1,-1)
	 res = x*y*z*(-Dip(8) - 2*Dip(9) + Dip(15))
	CASE (21212)
	! (1,0,1,1,0)
	 res = x*((x**2 + y**2)*Dip(9) - z**2*(Dip(8) + Dip(9) - Dip(15)))
	CASE (21213)
	! (1,0,1,1,1)
	 res = z*(-(x**2*Dip(8)) + (-x**2 + y**2 + z**2)*Dip(9) + x**2*Dip(15))
	CASE (21220)
	! (1,0,1,2,-2)
	 res = (y*z*(x**2*(x**2 + y**2 + 2*z**2)*Dip(11) + (x - y)*(x + y)*Dip(13) - &
x**2*(x**2 + y**2)*Dip(10)*sqrt3 + (x**2 + y**2)*((-3*x**2 + y**2 + &
z**2)*Dip(12) + x**2*Dip(16)*sqrt3)))/(x**2 + y**2)
	CASE (21221)
	! (1,0,1,2,-1)
	 res = x*y*((x**2 + y**2)*(Dip(12) - Dip(13)) - z**2*(Dip(11) + 3*Dip(12) + Dip(13) + &
(Dip(10) - Dip(16))*sqrt3))
	CASE (21222)
	! (1,0,1,2,0)
	 res = (x*z*((x**2 + y**2 - 2*z**2)*(Dip(10) - Dip(16)) + ((x**2 + y**2)*Dip(11) + &
2*(x**2 + y**2 - z**2)*Dip(12))*sqrt3))/2.
	CASE (21223)
	! (1,0,1,2,1)
	 res = x**4*Dip(12) + (y**2 + z**2)*(z**2*Dip(12) + y**2*Dip(13)) + &
x**2*(y**2*(Dip(12) + Dip(13)) - z**2*(Dip(11) + 2*Dip(12) + (Dip(10) - &
Dip(16))*sqrt3))
	CASE (21224)
	! (1,0,1,2,2)
	 res = (x*z*((x - y)*(x + y)*(x**2 + y**2 + 2*z**2)*Dip(11) - 2*(x**2 + y**2)*(x**2 - &
3*y**2 - z**2)*Dip(12) - 4*y**2*Dip(13) + (-x**4 + y**4)*(Dip(10) - &
Dip(16))*sqrt3))/(2.*(x**2 + y**2))
	CASE (1302)
	! (1,1,-1,0,0)
	 res = x*y*(-Dip(7) + Dip(14))
	CASE (1311)
	! (1,1,-1,1,-1)
	 res = x*(-(y**2*Dip(8)) + (x**2 - y**2 + z**2)*Dip(9) + y**2*Dip(15))
	CASE (1312)
	! (1,1,-1,1,0)
	 res = x*y*z*(-Dip(8) - 2*Dip(9) + Dip(15))
	CASE (1313)
	! (1,1,-1,1,1)
	 res = y*(-(x**2*Dip(8)) + (-x**2 + y**2 + z**2)*Dip(9) + x**2*Dip(15))
	CASE (1320)
	! (1,1,-1,2,-2)
	 res = (-(x**2*y**2*z**2*(x**2 + y**2 + 2*z**2)*Dip(11)) + (x**2 + y**2)**2*((x**2 - &
y**2)**2 + (x**2 + y**2)*z**2)*Dip(12) + (x**2*y**2*(x**2 + y**2) + (x**4 + &
y**4)*z**2)*Dip(13) - y**2*(x**3 + x*y**2)**2*(Dip(10) - &
Dip(16))*sqrt3)/(x**2 + y**2)**2
	CASE (1321)
	! (1,1,-1,2,-1)
	 res = (x*z*(y**2*z**2*Dip(11) + (x**2 + y**2)*(x**2 - 3*y**2 + z**2)*Dip(12) - &
x**2*Dip(13) - y**2*(x**2 + y**2)*(Dip(10) - Dip(16))*sqrt3))/(x**2 + y**2)
	CASE (1322)
	! (1,1,-1,2,0)
	 res = (x*y*((x**2 + y**2 - 2*z**2)*(Dip(10) - Dip(16)) + (-(z**2*(Dip(11) + &
4*Dip(12))) + (x**2 + y**2 + z**2)*Dip(13))*sqrt3))/2.
	CASE (1323)
	! (1,1,-1,2,1)
	 res = (y*z*(x**2*z**2*Dip(11) - y**2*Dip(13) - x**2*(x**2 + y**2)*Dip(10)*sqrt3 + &
(x**2 + y**2)*((-3*x**2 + y**2 + z**2)*Dip(12) + x**2*Dip(16)*sqrt3)))/(x**2 &
+ y**2)
	CASE (1324)
	! (1,1,-1,2,2)
	 res = (x*(x - y)*y*(x + y)*(-(z**2*(x**2 + y**2 + 2*z**2)*Dip(11)) - 4*(x**2 + &
y**2)**2*Dip(12) + (x**2 + y**2 - 2*z**2)*Dip(13) - (x**2 + y**2)**2*(Dip(10) &
- Dip(16))*sqrt3))/(2.*(x**2 + y**2)**2)
	CASE (11302)
	! (1,1,0,0,0)
	 res = x*z*(-Dip(7) + Dip(14))
	CASE (11311)
	! (1,1,0,1,-1)
	 res = x*y*z*(-Dip(8) - 2*Dip(9) + Dip(15))
	CASE (11312)
	! (1,1,0,1,0)
	 res = x*((x**2 + y**2)*Dip(9) - z**2*(Dip(8) + Dip(9) - Dip(15)))
	CASE (11313)
	! (1,1,0,1,1)
	 res = z*(-(x**2*Dip(8)) + (-x**2 + y**2 + z**2)*Dip(9) + x**2*Dip(15))
	CASE (11320)
	! (1,1,0,2,-2)
	 res = (y*z*(x**2*(x**2 + y**2 + 2*z**2)*Dip(11) + (x - y)*(x + y)*Dip(13) - &
x**2*(x**2 + y**2)*Dip(10)*sqrt3 + (x**2 + y**2)*((-3*x**2 + y**2 + &
z**2)*Dip(12) + x**2*Dip(16)*sqrt3)))/(x**2 + y**2)
	CASE (11321)
	! (1,1,0,2,-1)
	 res = x*y*((x**2 + y**2)*(Dip(12) - Dip(13)) - z**2*(Dip(11) + 3*Dip(12) + Dip(13) + &
(Dip(10) - Dip(16))*sqrt3))
	CASE (11322)
	! (1,1,0,2,0)
	 res = (x*z*((x**2 + y**2 - 2*z**2)*(Dip(10) - Dip(16)) + ((x**2 + y**2)*Dip(11) + &
2*(x**2 + y**2 - z**2)*Dip(12))*sqrt3))/2.
	CASE (11323)
	! (1,1,0,2,1)
	 res = x**4*Dip(12) + (y**2 + z**2)*(z**2*Dip(12) + y**2*Dip(13)) + &
x**2*(y**2*(Dip(12) + Dip(13)) - z**2*(Dip(11) + 2*Dip(12) + (Dip(10) - &
Dip(16))*sqrt3))
	CASE (11324)
	! (1,1,0,2,2)
	 res = (x*z*((x - y)*(x + y)*(x**2 + y**2 + 2*z**2)*Dip(11) - 2*(x**2 + y**2)*(x**2 - &
3*y**2 - z**2)*Dip(12) - 4*y**2*Dip(13) + (-x**4 + y**4)*(Dip(10) - &
Dip(16))*sqrt3))/(2.*(x**2 + y**2))
	CASE (21302)
	! (1,1,1,0,0)
	 res = (y**2 + z**2)*Dip(7) + x**2*Dip(14)
	CASE (21311)
	! (1,1,1,1,-1)
	 res = y*((y**2 + z**2)*Dip(8) + x**2*(-2*Dip(9) + Dip(15)))
	CASE (21312)
	! (1,1,1,1,0)
	 res = z*((y**2 + z**2)*Dip(8) + x**2*(-2*Dip(9) + Dip(15)))
	CASE (21313)
	! (1,1,1,1,1)
	 res = x*(y**2 + z**2)*(Dip(8) + 2*Dip(9)) + x**3*Dip(15)
	CASE (21320)
	! (1,1,1,2,-2)
	 res = (x*y*(-(x**2*z**2*(x**2 + y**2 + 2*z**2)*Dip(11)) - (y**4 + x**2*(y**2 + &
2*z**2))*Dip(13) + (x**2 + y**2)**2*(y**2 + z**2)*Dip(10)*sqrt3 + (x**2 + &
y**2)**2*(2*(-x**2 + y**2 + z**2)*Dip(12) + x**2*Dip(16)*sqrt3)))/(x**2 + &
y**2)**2
	CASE (21321)
	! (1,1,1,2,-1)
	 res = (y*z*(x**2*z**2*Dip(11) - 4*x**2*(x**2 + y**2)*Dip(12) + (2*x**2 + &
y**2)*Dip(13) + (x**2 + y**2)*((y**2 + z**2)*Dip(10) + &
x**2*Dip(16))*sqrt3))/(x**2 + y**2)
	CASE (21322)
	! (1,1,1,2,0)
	 res = (-((x**2 + y**2 - 2*z**2)*((y**2 + z**2)*Dip(10) + x**2*Dip(16))) - &
(x**2*z**2*(Dip(11) + 4*Dip(12)) + y**2*(x**2 + y**2 + &
z**2)*Dip(13))*sqrt3)/2.
	CASE (21323)
	! (1,1,1,2,1)
	 res = (x*z*(x**2*z**2*Dip(11) + 2*(-x**4 + y**4 + (x**2 + y**2)*z**2)*Dip(12) - &
y**2*Dip(13) + (x**2 + y**2)*((y**2 + z**2)*Dip(10) + &
x**2*Dip(16))*sqrt3))/(x**2 + y**2)
	CASE (21324)
	! (1,1,1,2,2)
	 res = (-(x**2*(x - y)*(x + y)*z**2*(x**2 + y**2 + 2*z**2)*Dip(11)) + 4*x**2*(x**2 + &
y**2)**2*(2*y**2 + z**2)*Dip(12) + y**2*(-x**4 + y**4 + 2*(3*x**2 + &
y**2)*z**2)*Dip(13) + (x - y)*(x + y)*(x**2 + y**2)**2*((y**2 + z**2)*Dip(10) &
+ x**2*Dip(16))*sqrt3)/(2.*(x**2 + y**2)**2)
	CASE (2002)
	! (2,-2,-1,0,0)
	 res = x*((x**2 - y**2 + z**2)*Dip(17) + y**2*Dip(28)*sqrt3)
	CASE (2011)
	! (2,-2,-1,1,-1)
	 res = (x*y*(-((x**4 + x**2*y**2 + 2*y**2*z**2)*Dip(18)) + (x**2 + y**2)**2*(x**2 - &
y**2 + z**2)*Dip(19) - y**2*z**2*(x**2 + y**2 + 2*z**2)*Dip(21) + (x**2 + &
y**2)**2*((x**2 - y**2 + z**2)*Dip(29) + ((x**2 + z**2)*Dip(20) + &
y**2*Dip(30))*sqrt3)))/(x**2 + y**2)**2
	CASE (2012)
	! (2,-2,-1,1,0)
	 res = (x*z*((-x**2 + y**2)*Dip(18) + (x**2 + y**2)*(x**2 - y**2 + z**2)*Dip(19) + &
y**2*((x**2 + y**2 + 2*z**2)*Dip(21) - (x**2 + y**2)*(2*Dip(29) + (Dip(20) - &
Dip(30))*sqrt3))))/(x**2 + y**2)
	CASE (2013)
	! (2,-2,-1,1,1)
	 res = ((x**2*y**4 + y**4*z**2 + x**4*(y**2 + z**2))*Dip(18) + x**2*(x**2 + &
y**2)**2*(x**2 - y**2 + z**2)*Dip(19) + y**2*(-(x**2*z**2*(x**2 + y**2 + &
2*z**2)*Dip(21)) + (x**2 + y**2)**2*((-x**2 + y**2 + z**2)*Dip(29) + &
x**2*(-Dip(20) + Dip(30))*sqrt3)))/(x**2 + y**2)**2
	CASE (2020)
	! (2,-2,-1,2,-2)
	 res = (y*(-((x - y)*(x + y)*(x**4 + y**2*z**2 + x**2*(y - z)*(y + z))*Dip(22)) + &
y**4*(y**2 + z**2)*(2*z**2*Dip(26) + y**2*Dip(31)) + x**8*(-Dip(26) + Dip(31) &
+ (Dip(23) + Dip(25))*sqrt3) + x**6*(z**2*Dip(26) + z**2*Dip(31) + &
3*y**2*Dip(32) + (y**2 + z**2)*(Dip(23) + Dip(25))*sqrt3) + &
x**2*y**2*(-4*z**4*(Dip(24) + Dip(27)) + y**4*(2*Dip(26) + 3*Dip(32) - &
(Dip(23) + Dip(25))*sqrt3) + y**2*z**2*(-2*Dip(24) + 3*Dip(26) - 2*Dip(27) + &
3*Dip(31) + (Dip(23) + Dip(25))*sqrt3)) + x**4*(2*z**4*Dip(26) - &
y**4*(-3*Dip(26) + 2*Dip(31) - 6*Dip(32) + (Dip(23) + Dip(25))*sqrt3) + &
y**2*z**2*(-2*Dip(24) + 2*Dip(26) - 2*Dip(27) + 3*Dip(31) + 2*(Dip(23) + &
Dip(25))*sqrt3))))/(x**2 + y**2)**2
	CASE (2021)
	! (2,-2,-1,2,-1)
	 res = (x*y*z*((-2*x**4 - x**2*y**2 + y**4 - 2*y**2*z**2)*Dip(22) - &
2*y**2*z**4*Dip(27) + y**6*(Dip(27) - 3*Dip(31) + 3*Dip(32) - (Dip(23) + &
Dip(25))*sqrt3) + x**6*(-3*Dip(26) + Dip(31) + (Dip(23) + Dip(25))*sqrt3) &
+ y**4*z**2*(2*Dip(24) - Dip(26) + Dip(27) + Dip(31) + (Dip(23) + &
Dip(25))*sqrt3) + x**4*(-3*(2*y**2 + z**2)*Dip(26) + y**2*Dip(27) - &
y**2*Dip(31) + z**2*Dip(31) + 3*y**2*Dip(32) + (y**2 + z**2)*(Dip(23) + &
Dip(25))*sqrt3) + x**2*y**2*(-(y**2*(3*Dip(26) - 2*Dip(27) + 5*Dip(31) - &
6*Dip(32) + (Dip(23) + Dip(25))*sqrt3)) + z**2*(2*Dip(24) - 4*Dip(26) + &
Dip(27) + 2*Dip(31) + 2*(Dip(23) + Dip(25))*sqrt3))))/(x**2 + y**2)**2
	CASE (2022)
	! (2,-2,-1,2,0)
	 res = (x*(-((x**2 + y**2)*(x**2 + y**2 - 2*z**2)*(x**2 - y**2 + z**2)*Dip(23)) + &
2*(-x**2 + y**2)*z**2*Dip(22)*sqrt3 - x**6*Dip(26)*sqrt3 + &
4*y**2*z**4*Dip(27)*sqrt3 + y**6*(2*Dip(26) - Dip(32))*sqrt3 - &
x**4*(z**2*Dip(26) + y**2*Dip(32))*sqrt3 + y**4*z**2*(-6*Dip(25) + &
(-2*Dip(24) + 3*Dip(26) + 2*(Dip(27) - 2*Dip(31) + Dip(32)))*sqrt3) + &
x**2*y**2*(y**2*(3*Dip(26) - 2*Dip(32))*sqrt3 + 2*z**2*(-3*Dip(25) + &
(-Dip(24) + Dip(26) + Dip(27) - 2*Dip(31) + Dip(32))*sqrt3))))/(2.*(x**2 + &
y**2))
	CASE (2023)
	! (2,-2,-1,2,1)
	 res = (z*((-x**6 + 2*x**2*y**4 + y**4*z**2 + x**4*(y**2 + z**2))*Dip(22) - &
y**6*(y**2 + z**2)*(2*Dip(26) - Dip(31)) + x**8*(Dip(26) + Dip(23)*sqrt3) + &
x**4*y**2*(z**2*(2*Dip(24) + 2*Dip(26) + Dip(27) + Dip(31)) - (y**2 - &
2*z**2)*Dip(23)*sqrt3 + y**2*(3*Dip(26) + 2*Dip(27) - 5*Dip(31) + 6*Dip(32) &
- 4*Dip(25)*sqrt3)) + x**6*((4*y**2 + z**2)*Dip(26) + (y**2 + &
z**2)*Dip(23)*sqrt3 + y**2*(Dip(27) - 3*Dip(31) + 3*Dip(32) - &
2*Dip(25)*sqrt3)) + x**2*y**2*(-2*z**4*Dip(27) + y**2*z**2*(2*Dip(24) - &
Dip(26) + Dip(27) + 2*Dip(31) + Dip(23)*sqrt3) - y**4*(2*Dip(26) - Dip(27) + &
Dip(31) - 3*Dip(32) + (Dip(23) + 2*Dip(25))*sqrt3))))/(x**2 + y**2)**2
	CASE (2024)
	! (2,-2,-1,2,2)
	 res = (x*(2*(2*x**2*y**2*(x**2 + y**2) + (x**4 + 3*y**4)*z**2)*Dip(22) + &
2*y**4*z**4*(2*Dip(24) + Dip(26) + 2*Dip(27)) + x**8*(-Dip(26) + &
Dip(23)*sqrt3) + y**8*(-2*Dip(26) + 4*Dip(31) - 3*Dip(32) + Dip(23)*sqrt3) &
+ y**6*z**2*(2*Dip(24) + Dip(26) + 2*Dip(27) - (Dip(23) + 2*Dip(25))*sqrt3) &
+ x**6*(z**2*(-3*Dip(26) + Dip(23)*sqrt3) + y**2*(Dip(26) - 4*Dip(31) + &
3*Dip(32) - 4*Dip(25)*sqrt3)) + x**2*y**2*(-4*z**4*(Dip(24) + 2*Dip(26) + &
Dip(27)) - y**4*(Dip(26) - 4*Dip(31) + 3*Dip(32) + 4*Dip(25)*sqrt3) - &
y**2*z**2*(5*Dip(26) + (Dip(23) + 4*Dip(25))*sqrt3)) - x**4*(2*z**4*Dip(26) &
+ y**2*z**2*(2*Dip(24) + 9*Dip(26) + 2*Dip(27) - Dip(23)*sqrt3 + &
2*Dip(25)*sqrt3) + y**4*(-3*Dip(26) + 4*Dip(31) - 3*Dip(32) + 2*(Dip(23) + &
4*Dip(25))*sqrt3))))/(2.*(x**2 + y**2)**2)
	CASE (12002)
	! (2,-2,0,0,0)
	 res = x*y*z*(-2*Dip(17) + Dip(28)*sqrt3)
	CASE (12011)
	! (2,-2,0,1,-1)
	 res = (x*z*((-x**2 + y**2)*Dip(18) - 2*y**2*(x**2 + y**2)*Dip(19) + (x**2 + &
y**2)*(x**2 - y**2 + z**2)*Dip(29) - y**2*(x**2 + y**2)*Dip(20)*sqrt3 + &
y**2*((x**2 + y**2 + 2*z**2)*Dip(21) + (x**2 + y**2)*Dip(30)*sqrt3)))/(x**2 &
+ y**2)
	CASE (12012)
	! (2,-2,0,1,0)
	 res = x*y*((x**2 + y**2)*(-Dip(21) + Dip(20)*sqrt3) + z**2*(-2*(Dip(19) + Dip(21) &
+ Dip(29)) + Dip(30)*sqrt3))
	CASE (12013)
	! (2,-2,0,1,1)
	 res = (y*z*((x - y)*(x + y)*Dip(18) - 2*x**2*(x**2 + y**2)*Dip(19) + (x**2 + &
y**2)*(-x**2 + y**2 + z**2)*Dip(29) + x**2*((x**2 + y**2 + 2*z**2)*Dip(21) - &
(x**2 + y**2)*(Dip(20) - Dip(30))*sqrt3)))/(x**2 + y**2)
	CASE (12020)
	! (2,-2,0,2,-2)
	 res = (z*(-((x**2 - y**2)**2*Dip(22)) + 2*x**2*y**2*(x**2 + y**2 + 2*z**2)*Dip(24) - &
x**6*Dip(26) + 2*x**4*y**2*Dip(26) + 2*x**2*y**4*Dip(26) - y**6*Dip(26) + &
4*x**2*y**2*z**2*Dip(26) + x**2*z**4*Dip(26) + y**2*z**4*Dip(26) + &
2*x**4*y**2*Dip(27) + 2*x**2*y**4*Dip(27) + 4*x**2*y**2*z**2*Dip(27) + &
x**6*Dip(31) - x**4*y**2*Dip(31) - x**2*y**4*Dip(31) + y**6*Dip(31) + &
x**4*z**2*Dip(31) + 2*x**2*y**2*z**2*Dip(31) + y**4*z**2*Dip(31) + &
3*x**4*y**2*Dip(32) + 3*x**2*y**4*Dip(32) - 2*x**2*y**2*(x**2 + y**2)*(Dip(23) &
+ Dip(25))*sqrt3))/(x**2 + y**2)
	CASE (12021)
	! (2,-2,0,2,-1)
	 res = (x*((-x**2 + y**2)*z**2*Dip(22) - 2*y**2*(x**2 + y**2)*z**2*Dip(24) + &
x**6*Dip(26) + x**4*y**2*Dip(26) - x**2*y**4*Dip(26) - y**6*Dip(26) - &
x**2*y**2*z**2*Dip(26) - y**4*z**2*Dip(26) - x**2*z**4*Dip(26) - &
y**2*z**4*Dip(26) - x**4*y**2*Dip(27) - 2*x**2*y**4*Dip(27) - y**6*Dip(27) - &
x**2*y**2*z**2*Dip(27) - y**4*z**2*Dip(27) + 2*y**2*z**4*Dip(27) + &
x**4*z**2*Dip(31) - 2*x**2*y**2*z**2*Dip(31) - 3*y**4*z**2*Dip(31) + &
x**2*z**4*Dip(31) + y**2*z**4*Dip(31) + 3*x**2*y**2*z**2*Dip(32) + &
3*y**4*z**2*Dip(32) + y**2*(x**2 + y**2)*(-2*z**2*Dip(23) + (x**2 + y**2 - &
z**2)*Dip(25))*sqrt3))/(x**2 + y**2)
	CASE (12022)
	! (2,-2,0,2,0)
	 res = (x*y*z*(2*(x**2 + y**2 - 2*z**2)*Dip(23) + 6*(x**2 + y**2)*Dip(25) + (2*(x**2 &
+ y**2)*Dip(24) + (x**2 + y**2 + 2*z**2)*Dip(26) - 2*(x**2 + y**2 + &
2*z**2)*Dip(27) - 4*z**2*Dip(31) - (x**2 + y**2 - &
2*z**2)*Dip(32))*sqrt3))/2.
	CASE (12023)
	! (2,-2,0,2,1)
	 res = (y*((x - y)*(x + y)*z**2*Dip(22) + y**2*((y**4 - z**4)*Dip(26) + z**2*(y**2 + &
z**2)*Dip(31)) - x**6*(Dip(26) + Dip(27) - Dip(25)*sqrt3) - &
x**2*(z**4*(Dip(26) - 2*Dip(27) - Dip(31)) - y**4*(Dip(26) - Dip(27) + &
Dip(25)*sqrt3) + y**2*z**2*(2*Dip(24) + Dip(26) + Dip(27) + 2*Dip(31) - &
3*Dip(32) + (2*Dip(23) + Dip(25))*sqrt3)) - x**4*(y**2*(Dip(26) + 2*Dip(27) &
- 2*Dip(25)*sqrt3) + z**2*(2*Dip(24) + Dip(26) + Dip(27) + 3*Dip(31) - &
3*Dip(32) + (2*Dip(23) + Dip(25))*sqrt3))))/(x**2 + y**2)
	CASE (12024)
	! (2,-2,0,2,2)
	 res = (x*(x - y)*y*(x + y)*z*(4*Dip(22) + 2*(x**2 + y**2 + 2*z**2)*Dip(24) + &
(5*(x**2 + y**2) + 4*z**2)*Dip(26) + 2*x**2*Dip(27) + 2*y**2*Dip(27) + &
4*z**2*Dip(27) - 4*x**2*Dip(31) - 4*y**2*Dip(31) + 3*x**2*Dip(32) + &
3*y**2*Dip(32) - 2*(x**2 + y**2)*(Dip(23) + Dip(25))*sqrt3))/(2.*(x**2 + &
y**2))
	CASE (22002)
	! (2,-2,1,0,0)
	 res = y*((-x**2 + y**2 + z**2)*Dip(17) + x**2*Dip(28)*sqrt3)
	CASE (22011)
	! (2,-2,1,1,-1)
	 res = ((x**2*y**4 + y**4*z**2 + x**4*(y**2 + z**2))*Dip(18) + y**2*(x**2 + &
y**2)**2*(-x**2 + y**2 + z**2)*Dip(19) + x**2*(-(y**2*z**2*(x**2 + y**2 + &
2*z**2)*Dip(21)) + (x**2 + y**2)**2*((x**2 - y**2 + z**2)*Dip(29) + &
y**2*(-Dip(20) + Dip(30))*sqrt3)))/(x**2 + y**2)**2
	CASE (22012)
	! (2,-2,1,1,0)
	 res = (y*z*((x - y)*(x + y)*Dip(18) + (-x**4 + y**4 + (x**2 + y**2)*z**2)*Dip(19) + &
x**2*((x**2 + y**2 + 2*z**2)*Dip(21) - (x**2 + y**2)*(2*Dip(29) + (Dip(20) - &
Dip(30))*sqrt3))))/(x**2 + y**2)
	CASE (22013)
	! (2,-2,1,1,1)
	 res = (x*y*(-((y**4 + x**2*(y**2 + 2*z**2))*Dip(18)) - (x**2 + y**2)**2*(x**2 - y**2 &
- z**2)*Dip(19) - x**2*z**2*(x**2 + y**2 + 2*z**2)*Dip(21) + (x**2 + &
y**2)**2*((y**2 + z**2)*(Dip(29) + Dip(20)*sqrt3) + x**2*(-Dip(29) + &
Dip(30)*sqrt3))))/(x**2 + y**2)**2
	CASE (22020)
	! (2,-2,1,2,-2)
	 res = (x*((x - y)*(x + y)*(y**4 - y**2*z**2 + x**2*(y**2 + z**2))*Dip(22) + &
x**8*Dip(31) + x**6*(2*(y**2 + z**2)*Dip(26) + z**2*Dip(31) + y**2*(3*Dip(32) &
- (Dip(23) + Dip(25))*sqrt3)) + y**4*(y**2 + z**2)*(2*z**2*Dip(26) + &
y**2*(-Dip(26) + Dip(31) + (Dip(23) + Dip(25))*sqrt3)) + &
x**4*(2*z**4*Dip(26) + y**2*z**2*(-2*Dip(24) + 3*Dip(26) - 2*Dip(27) + &
3*Dip(31) + (Dip(23) + Dip(25))*sqrt3) - y**4*(-3*Dip(26) + 2*Dip(31) - &
6*Dip(32) + (Dip(23) + Dip(25))*sqrt3)) + x**2*y**2*(-4*z**4*(Dip(24) + &
Dip(27)) + y**4*(3*Dip(32) + (Dip(23) + Dip(25))*sqrt3) + &
y**2*z**2*(-2*Dip(24) + 2*Dip(26) - 2*Dip(27) + 3*Dip(31) + 2*(Dip(23) + &
Dip(25))*sqrt3))))/(x**2 + y**2)**2
	CASE (22021)
	! (2,-2,1,2,-1)
	 res = (z*((2*x**4*y**2 + x**2*y**4 - y**6 + (x**4 + y**4)*z**2)*Dip(22) + &
x**8*(-2*Dip(26) + Dip(31)) + y**6*(y**2 + z**2)*(Dip(26) + Dip(23)*sqrt3) + &
x**2*y**2*(-2*z**4*Dip(27) + y**2*z**2*(2*Dip(24) + 2*Dip(26) + Dip(27) + &
Dip(31) + 2*Dip(23)*sqrt3) + y**4*(4*Dip(26) + Dip(27) - 3*Dip(31) + &
3*Dip(32) + (Dip(23) - 2*Dip(25))*sqrt3)) + x**4*y**2*(z**2*(2*Dip(24) - &
Dip(26) + Dip(27) + 2*Dip(31)) + (-y**2 + z**2)*Dip(23)*sqrt3 + &
y**2*(3*Dip(26) + 2*Dip(27) - 5*Dip(31) + 6*Dip(32) - 4*Dip(25)*sqrt3)) - &
x**6*(z**2*(2*Dip(26) - Dip(31)) + y**2*(2*Dip(26) - Dip(27) + Dip(31) - &
3*Dip(32) + (Dip(23) + 2*Dip(25))*sqrt3))))/(x**2 + y**2)**2
	CASE (22022)
	! (2,-2,1,2,0)
	 res = (y*((x**2 + y**2)*(x**2 + y**2 - 2*z**2)*(x**2 - y**2 - z**2)*Dip(23) + 2*(x - &
y)*(x + y)*z**2*Dip(22)*sqrt3 - y**4*(y**2 + z**2)*Dip(26)*sqrt3 + &
x**6*(2*Dip(26) - Dip(32))*sqrt3 + x**4*(-6*z**2*Dip(25) + (y**2*(3*Dip(26) &
- 2*Dip(32)) + z**2*(-2*Dip(24) + 3*Dip(26) + 2*(Dip(27) - 2*Dip(31) + &
Dip(32))))*sqrt3) + x**2*(4*z**4*Dip(27)*sqrt3 - y**4*Dip(32)*sqrt3 + &
2*y**2*z**2*(-3*Dip(25) + (-Dip(24) + Dip(26) + Dip(27) - 2*Dip(31) + &
Dip(32))*sqrt3))))/(2.*(x**2 + y**2))
	CASE (22023)
	! (2,-2,1,2,1)
	 res = (x*y*z*((x**4 - 2*y**4 - x**2*(y**2 + 2*z**2))*Dip(22) - 2*x**2*z**4*Dip(27) + &
(x**2 + y**2)**2*(-3*y**2*Dip(26) + x**2*Dip(27) - 3*x**2*Dip(31) + &
y**2*Dip(31) + 3*x**2*Dip(32) + (-x + y)*(x + y)*(Dip(23) + Dip(25))*sqrt3) &
+ (x**2 + y**2)*z**2*(2*x**2*Dip(24) - (x**2 + 3*y**2)*Dip(26) + x**2*Dip(27) &
+ x**2*Dip(31) + y**2*Dip(31) + (x**2 + y**2)*(Dip(23) + &
Dip(25))*sqrt3)))/(x**2 + y**2)**2
	CASE (22024)
	! (2,-2,1,2,2)
	 res = (y*(-2*(2*x**2*y**2*(x**2 + y**2) + (3*x**4 + y**4)*z**2)*Dip(22) + &
2*z**4*(2*x**2*(-x**2 + y**2)*Dip(24) + (-x**4 + 4*x**2*y**2 + y**4)*Dip(26) + &
2*x**2*(-x**2 + y**2)*Dip(27)) - (x**2 + y**2)**2*(-((x - y)*(x + y)*((2*x**2 &
- y**2)*Dip(26) + x**2*(-4*Dip(31) + 3*Dip(32)))) + (x**2 - &
y**2)**2*Dip(23)*sqrt3 - 4*x**2*y**2*Dip(25)*sqrt3) + (x**2 + &
y**2)*z**2*(y**4*(3*Dip(26) - Dip(23)*sqrt3) + 2*x**2*y**2*(Dip(24) + &
3*Dip(26) + Dip(27) + Dip(25)*sqrt3) - x**4*(2*Dip(24) + Dip(26) + 2*Dip(27) &
- (Dip(23) + 2*Dip(25))*sqrt3))))/(2.*(x**2 + y**2)**2)
	CASE (2102)
	! (2,-1,-1,0,0)
	 res = z*((x**2 - y**2 + z**2)*Dip(17) + y**2*Dip(28)*sqrt3)
	CASE (2111)
	! (2,-1,-1,1,-1)
	 res = (y*z*(-(x**2*Dip(18)) + (x**2 + y**2)*(x**2 - y**2 + z**2)*Dip(19) + &
y**2*z**2*Dip(21) + x**4*Dip(29) - y**4*Dip(29) + x**2*z**2*Dip(29) + &
y**2*z**2*Dip(29) + (x**2 + y**2)*((x**2 + z**2)*Dip(20) + &
y**2*Dip(30))*sqrt3))/(x**2 + y**2)
	CASE (2112)
	! (2,-1,-1,1,0)
	 res = x**2*Dip(18) + z**2*(x**2 - y**2 + z**2)*Dip(19) + y**2*((x**2 + y**2)*Dip(29) &
- z**2*(Dip(21) + Dip(29) + (Dip(20) - Dip(30))*sqrt3))
	CASE (2113)
	! (2,-1,-1,1,1)
	 res = (x*z*(-(x**2*Dip(18)) + (x**2 + y**2)*(x**2 - y**2 + z**2)*Dip(19) + &
y**2*(z**2*Dip(21) - (x**2 + y**2)*(2*Dip(29) + (Dip(20) - &
Dip(30))*sqrt3))))/(x**2 + y**2)
	CASE (2120)
	! (2,-1,-1,2,-2)
	 res = (x*y*z*(-2*x**2*(x**2 + y**2)*Dip(22) - 2*y**2*z**4*(Dip(24) + Dip(26)) + &
y**6*(Dip(24) + Dip(26) - 3*Dip(31) + 3*Dip(32) - (Dip(23) + Dip(25))*sqrt3) &
+ x**6*(-3*Dip(26) + Dip(31) + (Dip(23) + Dip(25))*sqrt3) + &
y**4*z**2*(Dip(24) - 2*Dip(26) + 2*Dip(27) + Dip(31) + (Dip(23) + &
Dip(25))*sqrt3) + x**4*(z**2*(-3*Dip(26) + Dip(31) + (Dip(23) + &
Dip(25))*sqrt3) + y**2*(Dip(24) - 5*Dip(26) - Dip(31) + 3*Dip(32) + (Dip(23) &
+ Dip(25))*sqrt3)) + x**2*y**2*(-(y**2*(-2*Dip(24) + Dip(26) + 5*Dip(31) - &
6*Dip(32) + (Dip(23) + Dip(25))*sqrt3)) + z**2*(Dip(24) - 5*Dip(26) + &
2*(Dip(27) + Dip(31) + (Dip(23) + Dip(25))*sqrt3)))))/(x**2 + y**2)**2
	CASE (2121)
	! (2,-1,-1,2,-1)
	 res = (y*(x**2*((x**2 + y**2)**2 - z**4)*Dip(22) + 2*x**6*Dip(26) + y**6*Dip(31) + &
y**2*z**4*(Dip(24) + Dip(27) + Dip(31) + (Dip(23) + Dip(25))*sqrt3) - &
y**4*z**2*(Dip(24) - Dip(26) + Dip(27) + 2*Dip(31) - 3*Dip(32) + (Dip(23) + &
Dip(25))*sqrt3) + x**2*(2*y**4*(Dip(26) + Dip(31)) - y**2*z**2*(Dip(24) - &
2*Dip(26) + Dip(27) + Dip(31) - 3*Dip(32)) + z**4*(-Dip(26) + Dip(31) + &
(Dip(23) + Dip(25))*sqrt3)) + x**4*(y**2*(4*Dip(26) + Dip(31)) + &
z**2*(Dip(26) + Dip(31) + (Dip(23) + Dip(25))*sqrt3))))/(x**2 + y**2)
	CASE (2122)
	! (2,-1,-1,2,0)
	 res = (z*(-((x**2 + y**2 - 2*z**2)*(x**2 - y**2 + z**2)*Dip(23)) - &
6*y**2*z**2*Dip(25) + 2*x**2*Dip(22)*sqrt3 - (-(y**2*(x**2 + y**2 - &
z**2)*Dip(24)) + ((x**2 + y**2)**2 + x**2*z**2)*Dip(26) + &
y**2*(2*z**2*(Dip(27) + Dip(31) - Dip(32)) - (x**2 + y**2)*(2*Dip(31) - &
Dip(32))))*sqrt3))/2.
	CASE (2123)
	! (2,-1,-1,2,1)
	 res = (x*(x**2*((x**2 + y**2)**2 - z**4)*Dip(22) - y**2*(x**2 + y**2)**2*(2*Dip(26) &
- Dip(31)) + z**4*(x**2*Dip(26) + y**2*(Dip(24) + 2*Dip(26) + Dip(27)) + (x**2 &
+ y**2)*Dip(23)*sqrt3) + (x**2 + y**2)*z**2*((x**2 + y**2)*Dip(26) + (x - &
y)*(x + y)*Dip(23)*sqrt3 - y**2*(Dip(24) + Dip(27) + 3*Dip(31) - 3*Dip(32) + &
2*Dip(25)*sqrt3))))/(x**2 + y**2)
	CASE (2124)
	! (2,-1,-1,2,2)
	 res = -(z*(2*(x**6 - x**2*y**4)*Dip(22) - 2*y**4*z**4*Dip(24) + x**8*(Dip(26) - &
Dip(23)*sqrt3) + y**8*(Dip(24) - Dip(26) - 2*Dip(31) + 3*Dip(32) - &
Dip(23)*sqrt3) + y**6*z**2*(Dip(24) - 2*Dip(26) + 2*(Dip(27) + Dip(31)) + &
(Dip(23) + 2*Dip(25))*sqrt3) - x**6*(z**2*(-3*Dip(26) + Dip(23)*sqrt3) + &
y**2*(Dip(24) + 6*Dip(26) - 6*Dip(31) + 3*Dip(32) - 4*Dip(25)*sqrt3)) + &
x**2*y**2*(2*z**4*(Dip(24) + 3*Dip(26)) + y**4*(Dip(24) - 10*Dip(26) + &
2*Dip(31) + 3*Dip(32) + 4*Dip(25)*sqrt3) + y**2*z**2*(-3*Dip(26) + 4*Dip(31) &
+ (Dip(23) + 4*Dip(25))*sqrt3)) + x**4*(2*z**4*Dip(26) - y**4*(Dip(24) + &
16*Dip(26) - 10*Dip(31) + 3*Dip(32) - 2*(Dip(23) + 4*Dip(25))*sqrt3) - &
y**2*z**2*(Dip(24) + Dip(23)*sqrt3 - 2*(Dip(26) - Dip(27) + Dip(31) + &
Dip(25)*sqrt3)))))/(2.*(x**2 + y**2)**2)
	CASE (12102)
	! (2,-1,0,0,0)
	 res = y*((x**2 + y**2 - z**2)*Dip(17) + z**2*Dip(28)*sqrt3)
	CASE (12111)
	! (2,-1,0,1,-1)
	 res = x**2*Dip(18) + y**2*(x**2 + y**2 - z**2)*Dip(19) + z**2*((x**2 + z**2)*Dip(29) &
- y**2*(Dip(21) + Dip(29) + (Dip(20) - Dip(30))*sqrt3))
	CASE (12112)
	! (2,-1,0,1,0)
	 res = y*z*((x**2 + y**2 - z**2)*Dip(19) + (x**2 + y**2)*Dip(21) + (x**2 + y**2 - &
z**2)*Dip(29) + ((x**2 + y**2)*Dip(20) + z**2*Dip(30))*sqrt3)
	CASE (12113)
	! (2,-1,0,1,1)
	 res = x*y*(-Dip(18) + (x**2 + y**2 - z**2)*Dip(19) - z**2*(Dip(21) + 2*Dip(29) + &
(Dip(20) - Dip(30))*sqrt3))
	CASE (12120)
	! (2,-1,0,2,-2)
	 res = (x*((x**4 - y**4)*Dip(22) - y**2*(x**2 + y**2 - z**2)*(x**2 + y**2 + &
2*z**2)*Dip(24) + z**2*((-2*x**4 + y**4 - x**2*(y**2 + 2*z**2))*Dip(26) + &
(x**2 + y**2)*(-2*y**2*Dip(27) + (x**2 - 3*y**2 + z**2)*Dip(31) + &
3*y**2*Dip(32))) + y**2*(x**2 + y**2)*((x**2 + y**2 - z**2)*Dip(23) - &
2*z**2*Dip(25))*sqrt3))/(x**2 + y**2)
	CASE (12121)
	! (2,-1,0,2,-1)
	 res = z*(x**2*Dip(22) + (x**2 + z**2)*(2*x**2*Dip(26) + z**2*Dip(31)) + &
y**4*(Dip(24) + Dip(27) + Dip(31) + (Dip(23) + Dip(25))*sqrt3) + &
y**2*(x**2*(Dip(24) + 2*Dip(26) + Dip(27) + Dip(31) + (Dip(23) + &
Dip(25))*sqrt3) - z**2*(Dip(24) - Dip(26) + Dip(27) + 2*Dip(31) - 3*Dip(32) &
+ (Dip(23) + Dip(25))*sqrt3)))
	CASE (12122)
	! (2,-1,0,2,0)
	 res = (y*(-((x**2 + y**2 - 2*z**2)*(x**2 + y**2 - z**2)*Dip(23)) + 6*(x**2 + &
y**2)*z**2*Dip(25) - ((x**2 + y**2)*(x**2 + y**2 - z**2)*Dip(24) + z**2*((x**2 &
+ y**2)*Dip(26) - 2*(x**2 + y**2)*Dip(27) - 2*(x**2 + y**2 - z**2)*Dip(31) + &
(x**2 + y**2 - 2*z**2)*Dip(32)))*sqrt3))/2.
	CASE (12123)
	! (2,-1,0,2,1)
	 res = x*y*z*(-Dip(22) + (x**2 + y**2 - z**2)*Dip(24) - (2*(x**2 + y**2) + &
z**2)*Dip(26) + x**2*Dip(27) + y**2*Dip(27) - z**2*Dip(27) + x**2*Dip(31) + &
y**2*Dip(31) - 3*z**2*Dip(31) + 3*z**2*Dip(32) + (x**2 + y**2 - z**2)*(Dip(23) &
+ Dip(25))*sqrt3)
	CASE (12124)
	! (2,-1,0,2,2)
	 res = (y*(-4*x**2*(x**2 + y**2)*Dip(22) - (x - y)*(x + y)*(x**2 + y**2 - z**2)*(x**2 &
+ y**2 + 2*z**2)*Dip(24) + z**2*((7*x**4 + 8*x**2*y**2 + y**4 + 2*(3*x**2 + &
y**2)*z**2)*Dip(26) + 2*(-x**4 + y**4)*Dip(27) - 2*(x**2 + y**2)*(3*x**2 - &
y**2 + z**2)*Dip(31) + 3*(x**4 - y**4)*Dip(32)) + (x**4 - y**4)*((x**2 + y**2 &
- z**2)*Dip(23) - 2*z**2*Dip(25))*sqrt3))/(2.*(x**2 + y**2))
	CASE (22102)
	! (2,-1,1,0,0)
	 res = x*y*z*(-2*Dip(17) + Dip(28)*sqrt3)
	CASE (22111)
	! (2,-1,1,1,-1)
	 res = (x*z*(-(x**2*Dip(18)) - 2*y**2*(x**2 + y**2)*Dip(19) + (x**2 + y**2)*(x**2 - &
y**2 + z**2)*Dip(29) - y**2*(x**2 + y**2)*Dip(20)*sqrt3 + y**2*(z**2*Dip(21) &
+ (x**2 + y**2)*Dip(30)*sqrt3)))/(x**2 + y**2)
	CASE (22112)
	! (2,-1,1,1,0)
	 res = -(x*y*(Dip(18) - (x**2 + y**2)*Dip(29) + z**2*(2*Dip(19) + Dip(21) + Dip(29) + &
(Dip(20) - Dip(30))*sqrt3)))
	CASE (22113)
	! (2,-1,1,1,1)
	 res = (y*z*((2*x**2 + y**2)*Dip(18) - x**2*(-(z**2*Dip(21)) + 2*(x**2 + &
y**2)*(Dip(19) + Dip(29))) + (x**2 + y**2)*((y**2 + z**2)*Dip(20) + &
x**2*Dip(30))*sqrt3))/(x**2 + y**2)
	CASE (22120)
	! (2,-1,1,2,-2)
	 res = (z*((-x**6 + x**4*y**2 + 3*x**2*y**4 + y**6)*Dip(22) + &
z**4*(-2*x**2*y**2*Dip(24) + (x**4 + y**4)*Dip(26)) + (x**2 + &
y**2)*z**2*(x**2*y**2*Dip(24) + x**2*(y**2*(Dip(26) + 2*Dip(27)) + (x**2 + &
y**2)*Dip(31)) + y**2*(x**2 + y**2)*Dip(25)*sqrt3) + (x**2 + &
y**2)**2*(x**4*(-Dip(26) + Dip(31)) + y**4*(-Dip(26) + Dip(25)*sqrt3) + &
x**2*y**2*(Dip(24) + 2*Dip(26) - 3*Dip(31) + 3*Dip(32) - (2*Dip(23) + &
Dip(25))*sqrt3))))/(x**2 + y**2)**2
	CASE (22121)
	! (2,-1,1,2,-1)
	 res = (x*(-((y**4 + x**2*(y**2 + z**2))*Dip(22)) + x**6*Dip(26) + y**6*(-Dip(26) + &
Dip(31)) + y**2*z**4*(Dip(24) + Dip(27) + Dip(31)) + x**4*(y**2*Dip(26) + &
(y**2 + z**2)*Dip(31)) - y**4*z**2*(Dip(24) + Dip(27) + 2*Dip(31) - 3*Dip(32) &
+ 2*(Dip(23) + Dip(25))*sqrt3) - x**2*(y**4*(Dip(26) - 2*Dip(31)) + &
z**4*(Dip(26) - Dip(31)) + y**2*z**2*(Dip(24) + Dip(27) + Dip(31) - 3*Dip(32) &
+ 2*(Dip(23) + Dip(25))*sqrt3))))/(x**2 + y**2)
	CASE (22122)
	! (2,-1,1,2,0)
	 res = (x*y*z*(-(z**2*(4*Dip(23) + 6*Dip(25) + (2*Dip(22) + Dip(24) - Dip(26) + &
2*(Dip(27) + Dip(31) - Dip(32)))*sqrt3)) + (x**2 + y**2)*(2*Dip(23) + &
(-2*Dip(22) + Dip(24) + 2*Dip(31) - Dip(32))*sqrt3)))/2.
	CASE (22123)
	! (2,-1,1,2,1)
	 res = (y*(-((x**4 - y**2*z**2 + x**2*(y**2 - 2*z**2))*Dip(22)) + (x**2 + &
y**2)**2*((-x**2 + y**2)*Dip(26) + x**2*Dip(31)) + z**4*(-(y**2*Dip(26)) + &
x**2*(Dip(24) + Dip(27)) + (x**2 + y**2)*Dip(25)*sqrt3) - (x**2 + &
y**2)*z**2*(-(y**2*Dip(25)*sqrt3) + x**2*(Dip(24) + Dip(27) + 3*Dip(31) - &
3*Dip(32) + (2*Dip(23) + Dip(25))*sqrt3))))/(x**2 + y**2)
	CASE (22124)
	! (2,-1,1,2,2)
	 res = (x*y*z*(2*(x**2 + y**2)*(3*x**2 + y**2)*Dip(22) + 2*y**2*z**4*(Dip(24) + &
Dip(26)) + x**6*(Dip(24) + 4*Dip(26) - 6*Dip(31) + 3*Dip(32) - &
2*Dip(23)*sqrt3) - y**6*(Dip(24) + 4*Dip(26) - 2*Dip(31) + 3*Dip(32) - &
2*(Dip(23) + 2*Dip(25))*sqrt3) - y**4*z**2*(Dip(24) + Dip(26) + 2*(Dip(27) + &
Dip(31) - Dip(25)*sqrt3)) + x**2*(-2*z**4*(Dip(24) + Dip(26)) - &
4*y**2*z**2*(Dip(31) - Dip(25)*sqrt3) - y**4*(Dip(24) + 4*Dip(26) + &
2*Dip(31) + 3*Dip(32) - 2*(Dip(23) + 4*Dip(25))*sqrt3)) + &
x**4*(y**2*(Dip(24) + 4*Dip(26) - 10*Dip(31) + 3*Dip(32) - 2*Dip(23)*sqrt3 + &
4*Dip(25)*sqrt3) + z**2*(Dip(24) + Dip(26) + 2*(Dip(27) - Dip(31) + &
Dip(25)*sqrt3)))))/(2.*(x**2 + y**2)**2)
	CASE (2202)
	! (2,0,-1,0,0)
	 res = -(y*((x**2 + y**2 - 2*z**2)*Dip(28) + 2*z**2*Dip(17)*sqrt3))/2.
	CASE (2211)
	! (2,0,-1,1,-1)
	 res = (-((x**2 + y**2 - 2*z**2)*((x**2 + z**2)*Dip(20) + y**2*Dip(30))) - &
(x**2*Dip(18) + y**2*z**2*(2*Dip(19) + Dip(21) + 2*Dip(29)))*sqrt3)/2.
	CASE (2212)
	! (2,0,-1,1,0)
	 res = -(y*z**3*(Dip(20) - Dip(30) + Dip(19)*sqrt3)) + (y*(x**2 + y**2)*z*(Dip(20) &
- Dip(30) + (Dip(21) + 2*Dip(29))*sqrt3))/2.
	CASE (2213)
	! (2,0,-1,1,1)
	 res = (x*y*((x**2 + y**2 - 2*z**2)*(Dip(20) - Dip(30)) + (Dip(18) - z**2*(2*Dip(19) &
+ Dip(21) + 2*Dip(29)))*sqrt3))/2.
	CASE (2220)
	! (2,0,-1,2,-2)
	 res = (x*((-x**4 + x**2*z**2 + 2*z**4)*Dip(25) - x**2*(x**2 + z**2)*Dip(22)*sqrt3 &
+ 4*z**4*Dip(24)*sqrt3 + 2*z**2*(-x + z)*(x + z)*Dip(26)*sqrt3 - &
(4*x**2*z**4*(Dip(24) + Dip(26))*sqrt3)/(x**2 + y**2) + y**4*(Dip(25) + &
(Dip(22) + Dip(26) - Dip(32))*sqrt3) + y**2*(x**2*(Dip(26) - &
Dip(32))*sqrt3 + z**2*(-6*Dip(23) - 3*Dip(25) + (Dip(22) + 2*(Dip(24) + &
2*Dip(26) - Dip(27) - 2*Dip(31) + Dip(32)))*sqrt3))))/2.
	CASE (2221)
	! (2,0,-1,2,-1)
	 res = (2*z**5*Dip(25) - z**3*(6*y**2*Dip(23) - (x**2 - 3*y**2)*Dip(25) + &
(x**2*(Dip(22) - 2*Dip(26)) + y**2*(2*Dip(24) + Dip(27) + 2*Dip(31) - &
2*Dip(32)))*sqrt3) - (x**2 + y**2)*z*((x - y)*(x + y)*Dip(25) + &
x**2*Dip(22)*sqrt3 + (-2*x**2*Dip(26) + y**2*(Dip(26) - Dip(27) - 2*Dip(31) &
+ Dip(32)))*sqrt3))/2.
	CASE (2222)
	! (2,0,-1,2,0)
	 res = (y*((x**2 + y**2)**2*(3*Dip(26) + Dip(32)) + 4*z**4*(Dip(32) - (Dip(23) + &
Dip(25))*sqrt3) + 2*(x**2 + y**2)*z**2*(3*Dip(24) + 3*Dip(27) + 6*Dip(31) - &
2*Dip(32) + (Dip(23) + Dip(25))*sqrt3)))/4.
	CASE (2223)
	! (2,0,-1,2,1)
	 res = (x*y*z*(Dip(22)*sqrt3 - z**2*(6*Dip(23) + 4*Dip(25) + (2*Dip(24) + 2*Dip(26) &
+ Dip(27) + 2*Dip(31) - 2*Dip(32))*sqrt3) + (x**2 + y**2)*(2*Dip(25) + &
(-3*Dip(26) + Dip(27) + 2*Dip(31) - Dip(32))*sqrt3)))/2.
	CASE (2224)
	! (2,0,-1,2,2)
	 res = (2*y*(x**2 + y**2)*(3*(-x + y)*(x + y)*z**2*Dip(23) + (x**2 + y**2 - &
2*z**2)*(2*x**2 + z**2)*Dip(25)) + y*(4*x**2*(x**2 + y**2)*(x**2 + y**2 + &
z**2)*Dip(22) + 2*(x - y)*(x + y)*z**2*(x**2 + y**2 + 2*z**2)*Dip(24) + &
x**6*Dip(26) + x**4*y**2*Dip(26) - x**2*y**4*Dip(26) - y**6*Dip(26) + &
10*x**4*z**2*Dip(26) + 8*x**2*y**2*z**2*Dip(26) - 2*y**4*z**2*Dip(26) + &
8*x**2*z**4*Dip(26) - 2*x**4*z**2*Dip(27) + 2*y**4*z**2*Dip(27) - &
4*x**4*z**2*Dip(31) + 4*y**4*z**2*Dip(31) - (x**4 - y**4)*(x**2 + y**2 - &
2*z**2)*Dip(32))*sqrt3)/(4.*(x**2 + y**2))
	CASE (12202)
	! (2,0,0,0,0)
	 res = z**3*Dip(28) - ((x**2 + y**2)*z*(Dip(28) - 2*Dip(17)*sqrt3))/2.
	CASE (12211)
	! (2,0,0,1,-1)
	 res = (y*(x**2 + y**2)*z*(Dip(20) - Dip(30) + (2*Dip(19) + Dip(21))*sqrt3))/2. - &
y*z**3*(Dip(20) - Dip(30) + Dip(29)*sqrt3)
	CASE (12212)
	! (2,0,0,1,0)
	 res = (-((x**2 + y**2 - 2*z**2)*((x**2 + y**2)*Dip(20) + z**2*Dip(30))) - (x**2 + &
y**2)*((x**2 + y**2)*Dip(21) - 2*z**2*(Dip(19) + Dip(29)))*sqrt3)/2.
	CASE (12213)
	! (2,0,0,1,1)
	 res = (x*(x**2 + y**2)*z*(Dip(20) - Dip(30) + (2*Dip(19) + Dip(21))*sqrt3))/2. - &
x*z**3*(Dip(20) - Dip(30) + Dip(29)*sqrt3)
	CASE (12220)
	! (2,0,0,2,-2)
	 res = (x*y*z*(6*(x**2 + y**2)*Dip(23) + 2*(x**2 + y**2 - 2*z**2)*Dip(25) + (-2*(x**2 &
+ y**2 + 2*z**2)*Dip(24) + (x**2 + y**2 + 2*z**2)*Dip(26) + 2*(x**2 + &
y**2)*Dip(27) - 4*z**2*Dip(31) - (x**2 + y**2 - 2*z**2)*Dip(32))*sqrt3))/2.
	CASE (12221)
	! (2,0,0,2,-1)
	 res = -(y*(-6*(x**2 + y**2)*z**2*Dip(23) + (x**2 + y**2 - 2*z**2)*(x**2 + y**2 - &
z**2)*Dip(25) - 2*(x**2 + y**2)*z**2*Dip(24)*sqrt3 + ((x**2 + &
y**2)*z**2*Dip(26) + (x**2 + y**2 - z**2)*((x**2 + y**2)*Dip(27) - &
2*z**2*Dip(31)) + z**2*(x**2 + y**2 - 2*z**2)*Dip(32))*sqrt3))/2.
	CASE (12222)
	! (2,0,0,2,0)
	 res = z**5*Dip(32) + (x**2 + y**2)*z**3*(3*Dip(31) - Dip(32) + (Dip(23) + &
Dip(25))*sqrt3) - ((x**2 + y**2)**2*z*(6*Dip(24) - 3*Dip(26) + 6*Dip(27) - &
Dip(32) + 2*(Dip(23) + Dip(25))*sqrt3))/4.
	CASE (12223)
	! (2,0,0,2,1)
	 res = -(x*(-6*(x**2 + y**2)*z**2*Dip(23) + (x**2 + y**2 - 2*z**2)*(x**2 + y**2 - &
z**2)*Dip(25) - 2*(x**2 + y**2)*z**2*Dip(24)*sqrt3 + ((x**2 + &
y**2)*z**2*Dip(26) + (x**2 + y**2 - z**2)*((x**2 + y**2)*Dip(27) - &
2*z**2*Dip(31)) + z**2*(x**2 + y**2 - 2*z**2)*Dip(32))*sqrt3))/2.
	CASE (12224)
	! (2,0,0,2,2)
	 res = ((x - y)*(x + y)*z*(6*(x**2 + y**2)*Dip(23) + 2*(x**2 + y**2 - 2*z**2)*Dip(25) &
+ (-2*(x**2 + y**2 + 2*z**2)*Dip(24) + (x**2 + y**2 + 2*z**2)*Dip(26) + &
2*(x**2 + y**2)*Dip(27) - 4*z**2*Dip(31) - (x**2 + y**2 - &
2*z**2)*Dip(32))*sqrt3))/4.
	CASE (22202)
	! (2,0,1,0,0)
	 res = -(x*((x**2 + y**2 - 2*z**2)*Dip(28) + 2*z**2*Dip(17)*sqrt3))/2.
	CASE (22211)
	! (2,0,1,1,-1)
	 res = (x*y*((x**2 + y**2 - 2*z**2)*(Dip(20) - Dip(30)) + (Dip(18) - z**2*(2*Dip(19) &
+ Dip(21) + 2*Dip(29)))*sqrt3))/2.
	CASE (22212)
	! (2,0,1,1,0)
	 res = -(x*z**3*(Dip(20) - Dip(30) + Dip(19)*sqrt3)) + (x*(x**2 + y**2)*z*(Dip(20) &
- Dip(30) + (Dip(21) + 2*Dip(29))*sqrt3))/2.
	CASE (22213)
	! (2,0,1,1,1)
	 res = (-((x**2 + y**2 - 2*z**2)*((y**2 + z**2)*Dip(20) + x**2*Dip(30))) - &
(y**2*Dip(18) + x**2*z**2*(2*Dip(19) + Dip(21) + 2*Dip(29)))*sqrt3)/2.
	CASE (22220)
	! (2,0,1,2,-2)
	 res = (y*(2*z**4*((x**2 + y**2)*Dip(25) + (2*x**2*Dip(24) + (x - y)*(x + &
y)*Dip(26))*sqrt3) + (x**2 + y**2)**2*((x - y)*(x + y)*Dip(25) + ((x - y)*(x &
+ y)*Dip(22) + x**2*(Dip(26) - Dip(32)))*sqrt3) + (x**2 + &
y**2)*z**2*(-6*x**2*Dip(23) + (-3*x**2 + y**2)*Dip(25) + (x - y)*(x + &
y)*Dip(22)*sqrt3 + 2*(-(y**2*Dip(26)) + x**2*(Dip(24) + 2*Dip(26) - Dip(27) &
- 2*Dip(31) + Dip(32)))*sqrt3)))/(2.*(x**2 + y**2))
	CASE (22221)
	! (2,0,1,2,-1)
	 res = (x*y*z*(Dip(22)*sqrt3 - z**2*(6*Dip(23) + 4*Dip(25) + (2*Dip(24) + 2*Dip(26) &
+ Dip(27) + 2*Dip(31) - 2*Dip(32))*sqrt3) + (x**2 + y**2)*(2*Dip(25) + &
(-3*Dip(26) + Dip(27) + 2*Dip(31) - Dip(32))*sqrt3)))/2.
	CASE (22222)
	! (2,0,1,2,0)
	 res = (x*((x**2 + y**2)**2*(3*Dip(26) + Dip(32)) + 4*z**4*(Dip(32) - (Dip(23) + &
Dip(25))*sqrt3) + 2*(x**2 + y**2)*z**2*(3*Dip(24) + 3*Dip(27) + 6*Dip(31) - &
2*Dip(32) + (Dip(23) + Dip(25))*sqrt3)))/4.
	CASE (22223)
	! (2,0,1,2,1)
	 res = (2*z**5*Dip(25) - z**3*(6*x**2*Dip(23) + (3*x**2 - y**2)*Dip(25) + &
(y**2*(Dip(22) - 2*Dip(26)) + x**2*(2*Dip(24) + Dip(27) + 2*Dip(31) - &
2*Dip(32)))*sqrt3) - (x**2 + y**2)*z*((-x**2 + y**2)*Dip(25) + &
(y**2*(Dip(22) - 2*Dip(26)) + x**2*(Dip(26) - Dip(27) - 2*Dip(31) + &
Dip(32)))*sqrt3))/2.
	CASE (22224)
	! (2,0,1,2,2)
	 res = (x*(6*(-x**4 + y**4)*z**2*Dip(23) - 4*y**2*(x**2 + y**2)*Dip(22)*sqrt3 + &
4*z**4*((x**2 + y**2)*Dip(25) + ((x - y)*(x + y)*Dip(24) - &
2*y**2*Dip(26))*sqrt3) + 2*(x**2 + y**2)*z**2*(-((x**2 - 3*y**2)*Dip(25)) + &
(x - y)*(x + y)*Dip(24)*sqrt3 + ((x**2 - 5*y**2)*Dip(26) - (x - y)*(x + &
y)*(Dip(27) + 2*Dip(31) - Dip(32)))*sqrt3) + (x**2 + &
y**2)**2*(-4*y**2*Dip(25) + (x - y)*(x + y)*(Dip(26) - &
Dip(32))*sqrt3)))/(4.*(x**2 + y**2))
	CASE (2302)
	! (2,1,-1,0,0)
	 res = x*y*z*(-2*Dip(17) + Dip(28)*sqrt3)
	CASE (2311)
	! (2,1,-1,1,-1)
	 res = (x*z*((x**2 + 2*y**2)*Dip(18) - y**2*(-(z**2*Dip(21)) + 2*(x**2 + &
y**2)*(Dip(19) + Dip(29))) + (x**2 + y**2)*((x**2 + z**2)*Dip(20) + &
y**2*Dip(30))*sqrt3))/(x**2 + y**2)
	CASE (2312)
	! (2,1,-1,1,0)
	 res = -(x*y*(Dip(18) - (x**2 + y**2)*Dip(29) + z**2*(2*Dip(19) + Dip(21) + Dip(29) + &
(Dip(20) - Dip(30))*sqrt3)))
	CASE (2313)
	! (2,1,-1,1,1)
	 res = (y*z*(-(y**2*Dip(18)) - 2*x**2*(x**2 + y**2)*Dip(19) + (x**2 + y**2)*(-x**2 + &
y**2 + z**2)*Dip(29) + x**2*(z**2*Dip(21) - (x**2 + y**2)*(Dip(20) - &
Dip(30))*sqrt3)))/(x**2 + y**2)
	CASE (2320)
	! (2,1,-1,2,-2)
	 res = (z*((x**6 + 3*x**4*y**2 + x**2*y**4 - y**6)*Dip(22) + y**4*(-y**4 + &
z**4)*Dip(26) + y**6*(y**2 + z**2)*Dip(31) + x**8*(-Dip(26) + Dip(25)*sqrt3) &
+ x**6*(z**2*Dip(25)*sqrt3 + y**2*(Dip(24) - 3*Dip(31) + 3*Dip(32) + &
(-2*Dip(23) + Dip(25))*sqrt3)) + x**2*y**2*(-2*z**4*Dip(24) + &
y**2*z**2*(Dip(24) + Dip(26) + 2*(Dip(27) + Dip(31)) + Dip(25)*sqrt3) + &
y**4*(Dip(24) - Dip(31) + 3*Dip(32) - (2*Dip(23) + Dip(25))*sqrt3)) + &
x**4*(z**4*Dip(26) + y**2*z**2*(Dip(24) + Dip(26) + 2*Dip(27) + Dip(31) + &
2*Dip(25)*sqrt3) + y**4*(2*Dip(24) + 2*Dip(26) - 5*Dip(31) + 6*Dip(32) - &
(4*Dip(23) + Dip(25))*sqrt3))))/(x**2 + y**2)**2
	CASE (2321)
	! (2,1,-1,2,-1)
	 res = (x*(-((y**4 - 2*y**2*z**2 + x**2*(y - z)*(y + z))*Dip(22)) + x**6*Dip(26) + &
y**6*(-Dip(26) + Dip(31)) + y**2*z**4*(Dip(24) + Dip(27) + Dip(25)*sqrt3) + &
x**4*(y**2*(Dip(26) + Dip(31)) + z**2*Dip(25)*sqrt3) - y**4*z**2*(Dip(24) + &
Dip(27) + 3*Dip(31) - 3*Dip(32) + (2*Dip(23) + Dip(25))*sqrt3) - &
x**2*(y**4*(Dip(26) - 2*Dip(31)) + y**2*z**2*(Dip(24) + Dip(27) + 3*Dip(31) - &
3*Dip(32) + 2*Dip(23)*sqrt3) + z**4*(Dip(26) - Dip(25)*sqrt3))))/(x**2 + &
y**2)
	CASE (2322)
	! (2,1,-1,2,0)
	 res = (x*y*z*(-(z**2*(4*Dip(23) + 6*Dip(25) + (2*Dip(22) + Dip(24) - Dip(26) + &
2*(Dip(27) + Dip(31) - Dip(32)))*sqrt3)) + (x**2 + y**2)*(2*Dip(23) + &
(-2*Dip(22) + Dip(24) + 2*Dip(31) - Dip(32))*sqrt3)))/2.
	CASE (2323)
	! (2,1,-1,2,1)
	 res = (y*(-((x**4 + x**2*y**2 + y**2*z**2)*Dip(22)) + x**6*(-Dip(26) + Dip(31)) + &
y**2*((y**4 - z**4)*Dip(26) + z**2*(y**2 + z**2)*Dip(31)) + &
x**2*(y**4*(Dip(26) + Dip(31)) + z**4*(Dip(24) + Dip(27) + Dip(31)) - &
y**2*z**2*(Dip(24) + Dip(27) + Dip(31) - 3*Dip(32) + 2*(Dip(23) + &
Dip(25))*sqrt3)) - x**4*(y**2*(Dip(26) - 2*Dip(31)) + z**2*(Dip(24) + &
Dip(27) + 2*Dip(31) - 3*Dip(32) + 2*(Dip(23) + Dip(25))*sqrt3))))/(x**2 + &
y**2)
	CASE (2324)
	! (2,1,-1,2,2)
	 res = -(x*y*z*(2*(x**2 + y**2)*(x**2 + 3*y**2)*Dip(22) - 2*y**2*z**4*(Dip(24) + &
Dip(26)) + y**6*(Dip(24) + 4*Dip(26) - 6*Dip(31) + 3*Dip(32) - &
2*Dip(23)*sqrt3) - x**6*(Dip(24) + 4*Dip(26) - 2*Dip(31) + 3*Dip(32) - &
2*(Dip(23) + 2*Dip(25))*sqrt3) + y**4*z**2*(Dip(24) + Dip(26) + 2*(Dip(27) - &
Dip(31) + Dip(25)*sqrt3)) + x**2*(2*z**4*(Dip(24) + Dip(26)) - &
4*y**2*z**2*(Dip(31) - Dip(25)*sqrt3) + y**4*(Dip(24) + 4*Dip(26) - &
10*Dip(31) + 3*Dip(32) - 2*Dip(23)*sqrt3 + 4*Dip(25)*sqrt3)) + &
x**4*(-(y**2*(Dip(24) + 4*Dip(26) + 2*Dip(31) + 3*Dip(32) - 2*(Dip(23) + &
4*Dip(25))*sqrt3)) - z**2*(Dip(24) + Dip(26) + 2*(Dip(27) + Dip(31) - &
Dip(25)*sqrt3)))))/(2.*(x**2 + y**2)**2)
	CASE (12302)
	! (2,1,0,0,0)
	 res = x*((x**2 + y**2 - z**2)*Dip(17) + z**2*Dip(28)*sqrt3)
	CASE (12311)
	! (2,1,0,1,-1)
	 res = x*y*(-Dip(18) + (x**2 + y**2 - z**2)*Dip(19) - z**2*(Dip(21) + 2*Dip(29) + &
(Dip(20) - Dip(30))*sqrt3))
	CASE (12312)
	! (2,1,0,1,0)
	 res = x*z*((x**2 + y**2 - z**2)*Dip(19) + (x**2 + y**2)*Dip(21) + (x**2 + y**2 - &
z**2)*Dip(29) + ((x**2 + y**2)*Dip(20) + z**2*Dip(30))*sqrt3)
	CASE (12313)
	! (2,1,0,1,1)
	 res = y**2*Dip(18) + x**2*(x**2 + y**2 - z**2)*Dip(19) + z**2*((y**2 + z**2)*Dip(29) &
- x**2*(Dip(21) + Dip(29) + (Dip(20) - Dip(30))*sqrt3))
	CASE (12320)
	! (2,1,0,2,-2)
	 res = (y*((-x**4 + y**4)*Dip(22) - x**2*(x**2 + y**2 - z**2)*(x**2 + y**2 + &
2*z**2)*Dip(24) + z**4*(-2*y**2*Dip(26) + (x**2 + y**2)*Dip(31)) + x**2*(x**2 &
+ y**2)*(x**2 + y**2 - z**2)*Dip(23)*sqrt3 - (x**2 + &
y**2)*z**2*(y**2*(2*Dip(26) - Dip(31)) + x**2*(-Dip(26) + 2*Dip(27) + &
3*Dip(31) - 3*Dip(32) + 2*Dip(25)*sqrt3))))/(x**2 + y**2)
	CASE (12321)
	! (2,1,0,2,-1)
	 res = x*y*z*(-Dip(22) + (x**2 + y**2 - z**2)*Dip(24) - (2*(x**2 + y**2) + &
z**2)*Dip(26) + x**2*Dip(27) + y**2*Dip(27) - z**2*Dip(27) + x**2*Dip(31) + &
y**2*Dip(31) - 3*z**2*Dip(31) + 3*z**2*Dip(32) + (x**2 + y**2 - z**2)*(Dip(23) &
+ Dip(25))*sqrt3)
	CASE (12322)
	! (2,1,0,2,0)
	 res = (x*(-((x**2 + y**2 - 2*z**2)*(x**2 + y**2 - z**2)*Dip(23)) + 6*(x**2 + &
y**2)*z**2*Dip(25) - ((x**2 + y**2)*(x**2 + y**2 - z**2)*Dip(24) + z**2*((x**2 &
+ y**2)*Dip(26) - 2*(x**2 + y**2)*Dip(27) - 2*(x**2 + y**2 - z**2)*Dip(31) + &
(x**2 + y**2 - 2*z**2)*Dip(32)))*sqrt3))/2.
	CASE (12323)
	! (2,1,0,2,1)
	 res = z*(y**2*Dip(22) + (y**2 + z**2)*(2*y**2*Dip(26) + z**2*Dip(31)) + &
x**4*(Dip(24) + Dip(27) + Dip(31) + (Dip(23) + Dip(25))*sqrt3) + &
x**2*(y**2*(Dip(24) + 2*Dip(26) + Dip(27) + Dip(31) + (Dip(23) + &
Dip(25))*sqrt3) - z**2*(Dip(24) - Dip(26) + Dip(27) + 2*Dip(31) - 3*Dip(32) &
+ (Dip(23) + Dip(25))*sqrt3)))
	CASE (12324)
	! (2,1,0,2,2)
	 res = (x*(4*y**2*(x**2 + y**2)*Dip(22) - (x - y)*(x + y)*(x**2 + y**2 - z**2)*(x**2 &
+ y**2 + 2*z**2)*Dip(24) + (x**4 - y**4)*(x**2 + y**2 - z**2)*Dip(23)*sqrt3 &
+ z**2*(-((x**4 + 7*y**4 + 6*y**2*z**2 + 2*x**2*(4*y**2 + z**2))*Dip(26)) + &
2*(x**2 + y**2)*(-x**2 + 3*y**2 + z**2)*Dip(31) - (x**4 - y**4)*(2*Dip(27) - &
3*Dip(32) + 2*Dip(25)*sqrt3))))/(2.*(x**2 + y**2))
	CASE (22302)
	! (2,1,1,0,0)
	 res = z*((-x**2 + y**2 + z**2)*Dip(17) + x**2*Dip(28)*sqrt3)
	CASE (22311)
	! (2,1,1,1,-1)
	 res = (y*z*(-(y**2*Dip(18)) + (-x**4 + y**4 + (x**2 + y**2)*z**2)*Dip(19) + &
x**2*(z**2*Dip(21) - (x**2 + y**2)*(2*Dip(29) + (Dip(20) - &
Dip(30))*sqrt3))))/(x**2 + y**2)
	CASE (22312)
	! (2,1,1,1,0)
	 res = y**2*Dip(18) + z**2*(-x**2 + y**2 + z**2)*Dip(19) + x**2*((x**2 + &
y**2)*Dip(29) - z**2*(Dip(21) + Dip(29) + (Dip(20) - Dip(30))*sqrt3))
	CASE (22313)
	! (2,1,1,1,1)
	 res = (x*z*(-(y**2*Dip(18)) + (-x**4 + y**4 + (x**2 + y**2)*z**2)*Dip(19) + (x**2 + &
y**2)*((-x**2 + y**2)*Dip(29) + (y**2*Dip(20) + x**2*Dip(30))*sqrt3) + &
z**2*(x**2*Dip(21) + (x**2 + y**2)*(Dip(29) + Dip(20)*sqrt3))))/(x**2 + &
y**2)
	CASE (22320)
	! (2,1,1,2,-2)
	 res = (x*y*z*(-2*y**2*(x**2 + y**2)*Dip(22) - 2*x**2*z**4*(Dip(24) + Dip(26)) + &
(x**2 + y**2)**2*(x**2*(Dip(24) + Dip(26) - 3*Dip(31) + 3*Dip(32) - (Dip(23) + &
Dip(25))*sqrt3) + y**2*(-3*Dip(26) + Dip(31) + (Dip(23) + Dip(25))*sqrt3)) &
+ (x**2 + y**2)*z**2*(y**2*(-3*Dip(26) + Dip(31) + (Dip(23) + &
Dip(25))*sqrt3) + x**2*(Dip(24) - 2*Dip(26) + 2*Dip(27) + Dip(31) + (Dip(23) &
+ Dip(25))*sqrt3))))/(x**2 + y**2)**2
	CASE (22321)
	! (2,1,1,2,-1)
	 res = (y*(y**2*((x**2 + y**2)**2 - z**4)*Dip(22) - x**2*(x**2 + y**2)**2*(2*Dip(26) &
- Dip(31)) + z**4*(x**2*Dip(24) + (2*x**2 + y**2)*Dip(26) + x**2*Dip(27) + &
(x**2 + y**2)*Dip(23)*sqrt3) + (x**2 + y**2)*z**2*((x**2 + y**2)*Dip(26) + &
(-x**2 + y**2)*Dip(23)*sqrt3 - x**2*(Dip(24) + Dip(27) + 3*Dip(31) - &
3*Dip(32) + 2*Dip(25)*sqrt3))))/(x**2 + y**2)
	CASE (22322)
	! (2,1,1,2,0)
	 res = (z*((x**2 + y**2 - 2*z**2)*(x**2 - y**2 - z**2)*Dip(23) - 6*x**2*z**2*Dip(25) &
+ 2*y**2*Dip(22)*sqrt3 + (x**2*(x**2 + y**2 - z**2)*Dip(24) - ((x**2 + &
y**2)**2 + y**2*z**2)*Dip(26) + x**2*(-2*z**2*(Dip(27) + Dip(31) - Dip(32)) + &
(x**2 + y**2)*(2*Dip(31) - Dip(32))))*sqrt3))/2.
	CASE (22323)
	! (2,1,1,2,1)
	 res = (x*(y**2*((x**2 + y**2)**2 - z**4)*Dip(22) + x**6*Dip(31) + y**2*(y**2 + &
z**2)*(2*y**2*Dip(26) + z**2*(-Dip(26) + Dip(31) + (Dip(23) + &
Dip(25))*sqrt3)) + x**2*(y**4*(4*Dip(26) + Dip(31)) - y**2*z**2*(Dip(24) - &
2*Dip(26) + Dip(27) + Dip(31) - 3*Dip(32)) + z**4*(Dip(24) + Dip(27) + Dip(31) &
+ (Dip(23) + Dip(25))*sqrt3)) - x**4*(-2*y**2*(Dip(26) + Dip(31)) + &
z**2*(Dip(24) - Dip(26) + Dip(27) + 2*Dip(31) - 3*Dip(32) + (Dip(23) + &
Dip(25))*sqrt3))))/(x**2 + y**2)
	CASE (22324)
	! (2,1,1,2,2)
	 res = (z*(2*y**2*(-x**4 + y**4)*Dip(22) + x**8*(Dip(24) - Dip(26) - 2*Dip(31) + &
3*Dip(32) - Dip(23)*sqrt3) - y**4*(y**2 + z**2)*(-((y**2 + 2*z**2)*Dip(26)) &
+ y**2*Dip(23)*sqrt3) + x**6*(y**2*(Dip(24) - 10*Dip(26) + 2*Dip(31) + &
3*Dip(32) + 4*Dip(25)*sqrt3) + z**2*(Dip(24) - 2*Dip(26) + 2*(Dip(27) + &
Dip(31)) + (Dip(23) + 2*Dip(25))*sqrt3)) + x**4*(-((y**4 + 2*z**4)*Dip(24)) &
+ y**2*(-((16*y**2 + 3*z**2)*Dip(26)) + 2*(5*y**2 + 2*z**2)*Dip(31) - &
3*y**2*Dip(32) + (2*y**2 + z**2)*(Dip(23) + 4*Dip(25))*sqrt3)) + &
x**2*y**2*(2*z**4*(Dip(24) + 3*Dip(26)) - y**4*(Dip(24) + 6*Dip(26) - &
6*Dip(31) + 3*Dip(32) - 4*Dip(25)*sqrt3) - y**2*z**2*(Dip(24) + &
Dip(23)*sqrt3 - 2*(Dip(26) - Dip(27) + Dip(31) + &
Dip(25)*sqrt3)))))/(2.*(x**2 + y**2)**2)
	CASE (2402)
	! (2,2,-1,0,0)
	 res = -(y*(2*(2*x**2 + z**2)*Dip(17) + (-x**2 + y**2)*Dip(28)*sqrt3))/2.
	CASE (2411)
	! (2,2,-1,1,-1)
	 res = (-(x**2*(x**4 - y**4 + 2*(x**2 + 3*y**2)*z**2)*Dip(18)) - 2*(x**2*y + &
y**3)**2*(2*x**2 + z**2)*Dip(19) + y**2*(-x + y)*(x + y)*z**2*(x**2 + y**2 + &
2*z**2)*Dip(21) - 2*(x**2*y + y**3)**2*(2*x**2 + z**2)*Dip(29) + (x - y)*(x + &
y)*(x**2 + y**2)**2*((x**2 + z**2)*Dip(20) + y**2*Dip(30))*sqrt3)/(2.*(x**2 &
+ y**2)**2)
	CASE (2412)
	! (2,2,-1,1,0)
	 res = (y*(4*x**2*z*Dip(18) - 2*(x**2 + y**2)*(2*x**2*z + z**3)*Dip(19) + 2*(x - &
y)*(x + y)*z**3*Dip(21) + (x**4 - y**4)*z*(Dip(21) - 2*Dip(29) + (-Dip(20) + &
Dip(30))*sqrt3)))/(2.*(x**2 + y**2))
	CASE (2413)
	! (2,2,-1,1,1)
	 res = (x*y*((x - y)*(x + y)*(x**2 + y**2 - 2*z**2)*Dip(18) - 2*(x**2 + &
y**2)**2*(2*x**2 + z**2)*Dip(19) + 2*(x**2 + y**2)**2*(2*y**2 + z**2)*Dip(29) &
+ (-x**2 + y**2)*(z**2*(x**2 + y**2 + 2*z**2)*Dip(21) + (x**2 + &
y**2)**2*(Dip(20) - Dip(30))*sqrt3)))/(2.*(x**2 + y**2)**2)
	CASE (2420)
	! (2,2,-1,2,-2)
	 res = (x*(-(((x**2 - y**2)**2*(x**2 + y**2) + 2*(x**4 + 4*x**2*y**2 - &
y**4)*z**2)*Dip(22)) + 2*y**4*z**4*(2*Dip(24) + 3*Dip(26) + 2*Dip(27)) + &
x**8*Dip(25)*sqrt3 + y**8*(-Dip(26) + 4*Dip(31) - 3*Dip(32) + &
Dip(25)*sqrt3) + y**6*z**2*(2*(Dip(24) + 3*Dip(26) + Dip(27)) - (2*Dip(23) + &
Dip(25))*sqrt3) + x**6*(y**2*(5*Dip(26) - 4*Dip(31) + 3*Dip(32) - &
4*Dip(23)*sqrt3) + z**2*(2*Dip(26) + Dip(25)*sqrt3)) + &
x**4*(2*z**4*Dip(26) + y**2*z**2*(-2*Dip(24) + 6*Dip(26) - 2*Dip(27) + &
(-2*Dip(23) + Dip(25))*sqrt3) + y**4*(9*Dip(26) - 4*Dip(31) + 3*Dip(32) - &
2*(4*Dip(23) + Dip(25))*sqrt3)) + x**2*y**2*(-4*z**4*(Dip(24) + Dip(27)) + &
y**4*(3*Dip(26) + 4*Dip(31) - 3*Dip(32) - 4*Dip(23)*sqrt3) + &
y**2*z**2*(10*Dip(26) - (4*Dip(23) + Dip(25))*sqrt3))))/(2.*(x**2 + &
y**2)**2)
	CASE (2421)
	! (2,2,-1,2,-1)
	 res = -(z*(x**2*(x**4 - 5*y**4 + 6*y**2*z**2 + 2*x**2*(-2*y**2 + z**2))*Dip(22) - &
2*y**4*z**4*Dip(27) + x**8*(2*Dip(26) - Dip(25)*sqrt3) - y**8*(Dip(26) - &
Dip(27) + 2*Dip(31) - 3*Dip(32) + Dip(25)*sqrt3) + y**6*z**2*(2*Dip(24) - &
2*Dip(26) + Dip(27) + 2*Dip(31) + (2*Dip(23) + Dip(25))*sqrt3) + &
x**6*(-(y**2*(Dip(26) + Dip(27) - 6*Dip(31) + 3*Dip(32) - 4*Dip(23)*sqrt3)) &
+ z**2*(2*Dip(26) - Dip(25)*sqrt3)) + x**4*y**2*(2*(4*y**2 + &
z**2)*Dip(23)*sqrt3 - y**2*(9*Dip(26) + Dip(27) - 10*Dip(31) + 3*Dip(32) - &
2*Dip(25)*sqrt3) - z**2*(2*Dip(24) + 2*Dip(26) + Dip(27) - 2*Dip(31) + &
Dip(25)*sqrt3)) + x**2*y**2*(2*z**4*Dip(27) + y**4*(-7*Dip(26) + Dip(27) + &
2*Dip(31) + 3*Dip(32)) + 4*y**2*(y**2 + z**2)*Dip(23)*sqrt3 + &
y**2*z**2*(-6*Dip(26) + 4*Dip(31) + Dip(25)*sqrt3))))/(2.*(x**2 + y**2)**2)
	CASE (2422)
	! (2,2,-1,2,0)
	 res = (y*(2*(x**2 + y**2)*(x**2 + y**2 - 2*z**2)*(2*x**2 + z**2)*Dip(23) + &
8*x**2*z**2*Dip(22)*sqrt3 - 4*y**2*z**4*Dip(27)*sqrt3 + x**6*(5*Dip(26) - &
Dip(32))*sqrt3 + y**6*(-Dip(26) + Dip(32))*sqrt3 + x**2*((3*y**4 + &
4*y**2*z**2)*Dip(26) + 4*z**4*Dip(27) + y**4*Dip(32))*sqrt3 - &
2*y**4*z**2*(-3*Dip(25) + (-Dip(24) + Dip(26) + Dip(27) - 2*Dip(31) + &
Dip(32))*sqrt3) + x**4*(y**2*(9*Dip(26) - Dip(32))*sqrt3 + &
2*z**2*(-3*Dip(25) + (-Dip(24) + 3*Dip(26) + Dip(27) - 2*Dip(31) + &
Dip(32))*sqrt3))))/(4.*(x**2 + y**2))
	CASE (2423)
	! (2,2,-1,2,1)
	 res = -(x*y*z*((-5*x**4 - 4*x**2*y**2 + y**4 + 2*(x - y)*(x + y)*z**2)*Dip(22) - &
2*y**2*z**4*Dip(27) + y**4*z**2*(2*Dip(24) + 8*Dip(26) + Dip(27) - 2*Dip(31) + &
2*Dip(23)*sqrt3) + y**6*(9*Dip(26) + Dip(27) - 6*Dip(31) + 3*Dip(32) - &
2*Dip(25)*sqrt3) + x**6*(3*Dip(26) - Dip(27) + 2*Dip(31) - 3*Dip(32) + &
2*(2*Dip(23) + Dip(25))*sqrt3) + x**2*(2*z**4*Dip(27) + &
4*y**2*z**2*(3*Dip(26) - Dip(31)) + 4*y**2*(y**2 + z**2)*Dip(23)*sqrt3 + &
y**4*(21*Dip(26) + Dip(27) - 10*Dip(31) + 3*Dip(32) - 2*Dip(25)*sqrt3)) + &
x**4*(-(z**2*(2*Dip(24) - 4*Dip(26) + Dip(27) + 2*Dip(31))) + 2*(4*y**2 + &
z**2)*Dip(23)*sqrt3 + y**2*(15*Dip(26) - Dip(27) - 2*Dip(31) - 3*Dip(32) + &
2*Dip(25)*sqrt3))))/(2.*(x**2 + y**2)**2)
	CASE (2424)
	! (2,2,-1,2,2)
	 res = (y*(4*x**2*(x**4 - y**4 + 4*y**2*z**2)*Dip(22) - 4*y**4*z**4*(Dip(24) - &
Dip(26) + Dip(27)) + y**8*(Dip(26) + 3*Dip(32)) + x**8*(5*Dip(26) + 3*Dip(32) &
- 4*(Dip(23) + Dip(25))*sqrt3) + 2*y**6*z**2*(-Dip(24) + 2*Dip(26) - Dip(27) &
+ 2*Dip(31) + (Dip(23) + Dip(25))*sqrt3) - 2*x**6*(z**2*Dip(24) - 2*(y**2 + &
2*z**2)*Dip(26) + z**2*Dip(27) - 8*y**2*Dip(31) - 2*z**2*Dip(31) + (2*y**2 + &
z**2)*(Dip(23) + Dip(25))*sqrt3) + 2*x**2*y**2*(4*z**4*(Dip(24) + 3*Dip(26) &
+ Dip(27)) + 2*y**4*(-Dip(26) + 4*Dip(31) + (Dip(23) + Dip(25))*sqrt3) + &
y**2*z**2*(Dip(24) + 12*Dip(26) + Dip(27) + 6*Dip(31) + (Dip(23) + &
Dip(25))*sqrt3)) + 2*x**4*(-2*z**4*(Dip(24) - Dip(26) + Dip(27)) + &
y**2*z**2*(Dip(24) + 14*Dip(26) + Dip(27) + 6*Dip(31) - (Dip(23) + &
Dip(25))*sqrt3) + y**4*(-3*Dip(26) + 16*Dip(31) - 3*Dip(32) + 2*(Dip(23) + &
Dip(25))*sqrt3))))/(4.*(x**2 + y**2)**2)
	CASE (12402)
	! (2,2,0,0,0)
	 res = -((x - y)*(x + y)*z*(2*Dip(17) - Dip(28)*sqrt3))/2.
	CASE (12411)
	! (2,2,0,1,-1)
	 res = (y*z*(4*x**2*Dip(18) + 2*(-x**4 + y**4)*Dip(19) - 2*(x**2 + y**2)*(2*x**2 + &
z**2)*Dip(29) + (x - y)*(x + y)*((x**2 + y**2 + 2*z**2)*Dip(21) - (x**2 + &
y**2)*(Dip(20) - Dip(30))*sqrt3)))/(2.*(x**2 + y**2))
	CASE (12412)
	! (2,2,0,1,0)
	 res = -((x - y)*(x + y)*((x**2 + y**2)*(Dip(21) - Dip(20)*sqrt3) + &
z**2*(2*(Dip(19) + Dip(21) + Dip(29)) - Dip(30)*sqrt3)))/2.
	CASE (12413)
	! (2,2,0,1,1)
	 res = (x*z*(-4*y**2*Dip(18) + 2*(-x**4 + y**4)*Dip(19) + 2*(x**2 + y**2)*(2*y**2 + &
z**2)*Dip(29) + (x - y)*(x + y)*((x**2 + y**2 + 2*z**2)*Dip(21) - (x**2 + &
y**2)*(Dip(20) - Dip(30))*sqrt3)))/(2.*(x**2 + y**2))
	CASE (12420)
	! (2,2,0,2,-2)
	 res = (x*(x - y)*y*(x + y)*z*(4*Dip(22) + 2*(x**2 + y**2 + 2*z**2)*Dip(24) + &
(5*(x**2 + y**2) + 4*z**2)*Dip(26) + 2*x**2*Dip(27) + 2*y**2*Dip(27) + &
4*z**2*Dip(27) - 4*x**2*Dip(31) - 4*y**2*Dip(31) + 3*x**2*Dip(32) + &
3*y**2*Dip(32) - 2*(x**2 + y**2)*(Dip(23) + Dip(25))*sqrt3))/(2.*(x**2 + &
y**2))
	CASE (12421)
	! (2,2,0,2,-1)
	 res = -(y*(-4*x**2*z**2*Dip(22) + 2*y**2*z**4*(-Dip(26) + Dip(27) + Dip(31)) + &
x**6*(4*Dip(26) + Dip(27) - Dip(25)*sqrt3) + y**6*(-Dip(27) + &
Dip(25)*sqrt3) - y**4*z**2*(2*Dip(24) + Dip(26) + Dip(27) + 2*Dip(31) - &
3*Dip(32) + (2*Dip(23) + Dip(25))*sqrt3) + x**2*(-2*z**4*(Dip(26) + Dip(27) &
- Dip(31)) + 4*y**2*z**2*Dip(31) + y**4*(4*Dip(26) - Dip(27) + &
Dip(25)*sqrt3)) + x**4*(y**2*(8*Dip(26) + Dip(27) - Dip(25)*sqrt3) + &
z**2*(2*Dip(24) + Dip(26) + Dip(27) + 6*Dip(31) - 3*Dip(32) + (2*Dip(23) + &
Dip(25))*sqrt3))))/(2.*(x**2 + y**2))
	CASE (12422)
	! (2,2,0,2,0)
	 res = ((x - y)*(x + y)*z*(2*(x**2 + y**2 - 2*z**2)*Dip(23) + 6*(x**2 + y**2)*Dip(25) &
+ (2*(x**2 + y**2)*Dip(24) + (x**2 + y**2 + 2*z**2)*Dip(26) - 2*(x**2 + y**2 + &
2*z**2)*Dip(27) - 4*z**2*Dip(31) - (x**2 + y**2 - &
2*z**2)*Dip(32))*sqrt3))/4.
	CASE (12423)
	! (2,2,0,2,1)
	 res = (x*(-4*y**2*z**2*Dip(22) - 2*y**2*z**4*(Dip(26) + Dip(27) - Dip(31)) + &
y**6*(4*Dip(26) + Dip(27) - Dip(25)*sqrt3) + x**6*(-Dip(27) + &
Dip(25)*sqrt3) + y**4*z**2*(2*Dip(24) + Dip(26) + Dip(27) + 6*Dip(31) - &
3*Dip(32) + (2*Dip(23) + Dip(25))*sqrt3) + x**2*(4*y**2*z**2*Dip(31) + &
2*z**4*(-Dip(26) + Dip(27) + Dip(31)) + y**4*(8*Dip(26) + Dip(27) - &
Dip(25)*sqrt3)) - x**4*(y**2*(-4*Dip(26) + Dip(27) - Dip(25)*sqrt3) + &
z**2*(2*Dip(24) + Dip(26) + Dip(27) + 2*Dip(31) - 3*Dip(32) + (2*Dip(23) + &
Dip(25))*sqrt3))))/(2.*(x**2 + y**2))
	CASE (12424)
	! (2,2,0,2,2)
	 res = (z*(-16*x**2*y**2*Dip(22) + 4*y**2*z**4*Dip(26) + 4*y**4*z**2*(Dip(24) + &
Dip(26) + Dip(27) + Dip(31)) + x**6*(2*Dip(24) + Dip(26) + 2*Dip(27) + &
3*Dip(32) - 2*(Dip(23) + Dip(25))*sqrt3) + y**6*(2*Dip(24) + Dip(26) + &
2*Dip(27) + 3*Dip(32) - 2*(Dip(23) + Dip(25))*sqrt3) + x**4*(4*z**2*(Dip(24) &
+ Dip(26) + Dip(27) + Dip(31)) + y**2*(-2*Dip(24) - 17*Dip(26) - 2*Dip(27) + &
16*Dip(31) - 3*Dip(32) + 2*(Dip(23) + Dip(25))*sqrt3)) + &
x**2*(4*z**4*Dip(26) - 8*y**2*z**2*(Dip(24) + Dip(26) + Dip(27) - Dip(31)) + &
y**4*(-2*Dip(24) - 17*Dip(26) - 2*Dip(27) + 16*Dip(31) - 3*Dip(32) + &
2*(Dip(23) + Dip(25))*sqrt3))))/(4.*(x**2 + y**2))
	CASE (22402)
	! (2,2,1,0,0)
	 res = x*(2*y**2 + z**2)*Dip(17) + (x*(x - y)*(x + y)*Dip(28)*sqrt3)/2.
	CASE (22411)
	! (2,2,1,1,-1)
	 res = (x*y*((x - y)*(x + y)*(x**2 + y**2 - 2*z**2)*Dip(18) + 2*(x**2 + &
y**2)**2*(2*y**2 + z**2)*Dip(19) - 2*(x**2 + y**2)**2*(2*x**2 + z**2)*Dip(29) &
+ (-x**2 + y**2)*(z**2*(x**2 + y**2 + 2*z**2)*Dip(21) + (x**2 + &
y**2)**2*(Dip(20) - Dip(30))*sqrt3)))/(2.*(x**2 + y**2)**2)
	CASE (22412)
	! (2,2,1,1,0)
	 res = (x*z*(-4*y**2*Dip(18) + 2*(x**2 + y**2)*(2*y**2 + z**2)*Dip(19) + 2*(x - y)*(x &
+ y)*z**2*Dip(21) + (x**4 - y**4)*(Dip(21) - 2*Dip(29) + (-Dip(20) + &
Dip(30))*sqrt3)))/(2.*(x**2 + y**2))
	CASE (22413)
	! (2,2,1,1,1)
	 res = (y**2*(-x**4 + y**4 + 2*(3*x**2 + y**2)*z**2)*Dip(18) + 2*(x**3 + &
x*y**2)**2*(2*y**2 + z**2)*Dip(19) - x**2*(x - y)*(x + y)*z**2*(x**2 + y**2 + &
2*z**2)*Dip(21) + 2*(x**3 + x*y**2)**2*(2*y**2 + z**2)*Dip(29) + (x - y)*(x + &
y)*(x**2 + y**2)**2*((y**2 + z**2)*Dip(20) + x**2*Dip(30))*sqrt3)/(2.*(x**2 &
+ y**2)**2)
	CASE (22420)
	! (2,2,1,2,-2)
	 res = (y*(((x**2 - y**2)**2*(x**2 + y**2) + 2*(-x**4 + 4*x**2*y**2 + &
y**4)*z**2)*Dip(22) - 2*z**4*(2*x**2*(x - y)*(x + y)*Dip(24) + (3*x**4 + &
y**4)*Dip(26) + 2*x**2*(x - y)*(x + y)*Dip(27)) - (x**2 + &
y**2)**2*(x**2*(-((x**2 - 5*y**2)*Dip(26)) + (x - y)*(x + y)*(4*Dip(31) - &
3*Dip(32))) - 4*x**2*y**2*Dip(23)*sqrt3 + (x**2 - y**2)**2*Dip(25)*sqrt3) &
+ (x**2 + y**2)*z**2*(2*x**2*y**2*(Dip(24) - 2*Dip(26) + Dip(27) + &
Dip(23)*sqrt3) - y**4*(2*Dip(26) + Dip(25)*sqrt3) + x**4*(-2*(Dip(24) + &
3*Dip(26) + Dip(27)) + (2*Dip(23) + Dip(25))*sqrt3))))/(2.*(x**2 + y**2)**2)
	CASE (22421)
	! (2,2,1,2,-1)
	 res = (x*y*z*((x**4 - 5*y**4 + 2*y**2*z**2 - 2*x**2*(2*y**2 + z**2))*Dip(22) + &
2*y**2*z**4*Dip(27) - y**4*z**2*(2*Dip(24) - 4*Dip(26) + Dip(27) + 2*Dip(31) - &
2*Dip(23)*sqrt3) + x**6*(9*Dip(26) + Dip(27) - 6*Dip(31) + 3*Dip(32) - &
2*Dip(25)*sqrt3) + y**6*(3*Dip(26) - Dip(27) + 2*Dip(31) - 3*Dip(32) + &
2*(2*Dip(23) + Dip(25))*sqrt3) + x**4*(z**2*(2*Dip(24) + 8*Dip(26) + Dip(27) &
- 2*Dip(31)) + 2*(2*y**2 + z**2)*Dip(23)*sqrt3 + y**2*(21*Dip(26) + Dip(27) &
- 10*Dip(31) + 3*Dip(32) - 2*Dip(25)*sqrt3)) + x**2*(-2*z**4*Dip(27) + &
4*y**2*z**2*(3*Dip(26) - Dip(31) + Dip(23)*sqrt3) + y**4*(15*Dip(26) - &
Dip(27) - 2*Dip(31) - 3*Dip(32) + 2*(4*Dip(23) + &
Dip(25))*sqrt3))))/(2.*(x**2 + y**2)**2)
	CASE (22422)
	! (2,2,1,2,0)
	 res = (x*(-2*(x**2 + y**2)*(x**2 + y**2 - 2*z**2)*(2*y**2 + z**2)*Dip(23) - &
8*y**2*z**2*Dip(22)*sqrt3 - 4*y**2*z**4*Dip(27)*sqrt3 + x**6*(Dip(26) - &
Dip(32))*sqrt3 + y**6*(-5*Dip(26) + Dip(32))*sqrt3 + x**2*(-((9*y**4 + &
4*y**2*z**2)*Dip(26)) + 4*z**4*Dip(27) + y**4*Dip(32))*sqrt3 + &
2*y**4*z**2*(3*Dip(25) + Dip(24)*sqrt3 - (3*Dip(26) + Dip(27) - 2*Dip(31) + &
Dip(32))*sqrt3) - x**4*(y**2*(3*Dip(26) + Dip(32))*sqrt3 + &
2*z**2*(3*Dip(25) + Dip(24)*sqrt3 - (Dip(26) + Dip(27) - 2*Dip(31) + &
Dip(32))*sqrt3))))/(4.*(x**2 + y**2))
	CASE (22423)
	! (2,2,1,2,1)
	 res = (z*(y**2*(-5*x**4 - 4*x**2*y**2 + y**4 + 2*(3*x**2 + y**2)*z**2)*Dip(22) + &
y**6*(y**2 + z**2)*(2*Dip(26) - Dip(25)*sqrt3) - x**8*(Dip(26) - Dip(27) + &
2*Dip(31) - 3*Dip(32) + Dip(25)*sqrt3) + x**2*y**2*(2*z**4*Dip(27) - &
y**4*(Dip(26) + Dip(27) - 6*Dip(31) + 3*Dip(32) - 4*Dip(23)*sqrt3) - &
y**2*z**2*(2*Dip(24) + 2*Dip(26) + Dip(27) - 2*Dip(31) + (-2*Dip(23) + &
Dip(25))*sqrt3)) + x**6*(y**2*(-7*Dip(26) + Dip(27) + 2*Dip(31) + 3*Dip(32) &
+ 4*Dip(23)*sqrt3) + z**2*(2*Dip(24) - 2*Dip(26) + Dip(27) + 2*Dip(31) + &
(2*Dip(23) + Dip(25))*sqrt3)) + x**4*(-3*(3*y**4 + 2*y**2*z**2)*Dip(26) - &
(y**4 + 2*z**4)*Dip(27) + y**2*(2*(5*y**2 + 2*z**2)*Dip(31) - 3*y**2*Dip(32) + &
(2*y**2 + z**2)*(4*Dip(23) + Dip(25))*sqrt3))))/(2.*(x**2 + y**2)**2)
	CASE (22424)
	! (2,2,1,2,2)
	 res = (x*(4*y**2*(-x**4 + y**4 + 4*x**2*z**2)*Dip(22) - 4*y**4*z**4*(Dip(24) - &
Dip(26) + Dip(27)) + x**8*(Dip(26) + 3*Dip(32)) + y**8*(5*Dip(26) + 3*Dip(32) &
- 4*(Dip(23) + Dip(25))*sqrt3) - 2*y**6*z**2*(Dip(24) - 4*Dip(26) + Dip(27) &
- 2*Dip(31) + (Dip(23) + Dip(25))*sqrt3) + 2*x**6*(-(z**2*Dip(24)) + &
2*(-y**2 + z**2)*Dip(26) - z**2*Dip(27) + 8*y**2*Dip(31) + 2*z**2*Dip(31) + &
(2*y**2 + z**2)*(Dip(23) + Dip(25))*sqrt3) + 2*x**2*y**2*(4*z**4*(Dip(24) + &
3*Dip(26) + Dip(27)) + 2*y**4*(Dip(26) + 4*Dip(31) - (Dip(23) + &
Dip(25))*sqrt3) + y**2*z**2*(Dip(24) + 14*Dip(26) + Dip(27) + 6*Dip(31) - &
(Dip(23) + Dip(25))*sqrt3)) + 2*x**4*(-2*z**4*(Dip(24) - Dip(26) + Dip(27)) &
+ y**2*z**2*(Dip(24) + 12*Dip(26) + Dip(27) + 6*Dip(31) + (Dip(23) + &
Dip(25))*sqrt3) + y**4*(-3*Dip(26) + 16*Dip(31) - 3*Dip(32) + 2*(Dip(23) + &
Dip(25))*sqrt3))))/(4.*(x**2 + y**2)**2)
  CASE DEFAULT
	 WRITE(*,*) "BUG: No case for i=",i," which encodes (l1,m1,mr,l2,m2)=(",l1,",",m1,",",mr,",",l2,",",m2,") !"
	 STOP
   END SELECT
   slako_transformation_dipole = res
END FUNCTION
