"""
THIS IS VERY OLD STUFF
Run DFTB calculations to check that the behaviour of module was not broken during the development process.
Before performing any calculations you need to check that all tests are passed!
"""
import DFTB2
import AtomicData
import XYZ
import unittest
from numpy.linalg import norm

class TestDFTB(unittest.TestCase):
    """
    check that ground state energy and gradients are correct
    """
    # change this section for each molecule
    xyz_file = "DFTB/test_structures/h2.xyz" # path to geometry
    etot_expected = -17.1922513666 # total SCC ground state energy from Roland's program in eV
    en_tolerance = 6.0e-3 # relative tolerance
    grad_tolerance = 1.0e-3
    #
    def setUp(self):
        self.etot_expected /= AtomicData.hartree_to_eV
        self.atomlist = XYZ.read_xyz(self.xyz_file)[0]
        self.dftb2 = DFTB2.DFTB2(self.atomlist, \
                      parameter_set=getattr(self, "parameter_set", "hotbit"))
        self.dftb2.setGeometry(self.atomlist)
        self.dftb2.getEnergy(maxiter=100)
    def test_energy(self):
        """test that ground state energy agrees with Roland's program or hotbit"""
        self.etot = self.dftb2.getEnergies()[4]
        self.energies = self.dftb2.getEnergies()
        rel_dif = abs(self.etot-self.etot_expected)/max(abs(self.etot_expected),1)
        self.assertTrue(rel_dif < self.en_tolerance, \
                        "Relative energy difference exceeds tolerance: %e > %e.\nEtot            = %2.5f\nEtot (expected) = %2.5f\n%s" % (rel_dif, self.en_tolerance, self.etot, self.etot_expected, str(self.energies)))
    def test_gradient(self):
        """check that numerical and analytical gradients coincide"""
        grad_an = self.dftb2.getGradient(format="vector")
        grad_num = self.dftb2.getGradientNumerically(self.atomlist, gradOf="Etot", format="vector")
        rel_dif = norm(grad_num-grad_an)/max(norm(grad_num),1.0)
        self.assertTrue(rel_dif < self.grad_tolerance, "Relative difference between numerical and analytical gradients exceeds tolerance: %e > %e." % (rel_dif, self.grad_tolerance))

######## CHECK GROUND STATE ENERGIES AND GRADIENTS FOR DIFFERENT MOLECULES ########################


class Benzene(TestDFTB):
    xyz_file = "DFTB/test_structures/benzene.xyz"
    etot_expected = -340.432780186 # Roland
    en_tolerance = 5.0e-3
    grad_tolerance = 1.0e-3

class GoldDimer(TestDFTB):
    xyz_file = "DFTB/test_structures/gold_dimer.xyz"
    etot_expected = -154.660543242512 # hotbit
    en_tolerance = 1.5e-2 # have to compare with non-SCC calculation, so tolerance is higher
    grad_toleance = 1.0e-6


class Methane(TestDFTB):
    xyz_file = "DFTB/test_structures/methane.xyz"
    etot_expected = -86.3537944185 # Roland
    en_tolerance = 3.0e-2
    grad_toleance = 1.0e-6

"""
# the following tests are not passed
class Porphyrine(TestDFTB):
    xyz_file = "DFTB/test_structures/porphyrine.xyz"
    etot_expected = -1180.17558124 # Roland, SCC not fully converged
    en_tolerance = 1.0e-6
    grad_toleance = 1.0e-6

class Formonitrile(TestDFTB):
    xyz_file = "DFTB/test_structures/formonitrile.xyz"
    etot_expected = -122.8423 # Roland's program
    en_tolerance = 6.0e-2 # with hotbit parameters, so slightly different energy is expected
    grad_tolerance = 3.0e-2 # pretty high?
    parameter_set = "homegrown"

class Formaldehyde(TestDFTB):
    xyz_file = "DFTB/test_structures/formaldehyde.xyz"
    etot_expected = 0.0 
    en_tolerance = 10000 # only test that numerical and analytical gradients are the same
    # as we do not have an energy to compare with (Roland's program has not oxygen parameters)
    grad_tolerance = 1.0e-2
    parameter_set = "homegrown"
"""    

if __name__ == "__main__":
    unittest.main()

